/*!
Theme Name: Coral Dark
Theme URI: https://www.coralthemes.com/product/coral-dark-wordpress-theme/
Author: Coralthemes
Author URI: https://www.coralthemes.com
Description: Coral Dark is a free responsive theme with one-column or two-column layout, and built-in slideshow. The theme is optimized for SEO, and suitable e.g. for a portfolio gallery site or a photo blog that can be spectacular with its dark, black background. You can find a demo site here: https://www.coralthemes.com/demo/coraldark/ . More info can be found here: https://www.coralthemes.com/product/coral-dark-wordpress-theme/ . Further customization options are available in the pro version: https://www.coralthemes.com/product/coral-dark-pro-wordpress-theme/ . 
Version: 1.4
Requires at least: 5.0
Tested up to: 6.0
Requires PHP: 7.4
License: GNU General Public License v2 or later
License URI: http://www.gnu.org/licenses/gpl-2.0.html
Text Domain: coral-dark
Tags: one-column, two-columns, left-sidebar, custom-background, custom-logo, custom-menu, editor-style, featured-images, threaded-comments, translation-ready, blog, photography, portfolio
*/

/*--------------------------------------------------------------
>>> TABLE OF CONTENTS:
----------------------------------------------------------------
1.0 Normalize
2.0 Typography
3.0 Elements
4.0 Forms
5.0 Navigation
	5.1 Links
	5.2 Menus
6.0 Accessibility
7.0 Alignments
8.0 Clearings
9.0 Widgets
10.0 Content
	10.1 Posts and pages
	10.2 Asides
	10.3 Comments
11.0 Infinite scroll
12.0 Media
	12.1 Captions
	12.2 Galleries
--------------------------------------------------------------*/

/*--------------------------------------------------------------
1.0 Normalize (also with reset unsemantic)
--------------------------------------------------------------*/
html {
	font-family: sans-serif;
	-webkit-text-size-adjust: 100%;
	-ms-text-size-adjust:     100%;
}
/* unsemantic  */
a,
abbr,
acronym,
address,
applet,
article,
aside,
audio,
b,
big,
blockquote,
body,
canvas,
caption,
center,
cite,
code,
dd,
del,
details,
dfn,
dialog,
div,
dl,
dt,
em,
embed,
fieldset,
figcaption,
figure,
font,
footer,
form,
h1,
h2,
h3,
h4,
h5,
h6,
header,
hgroup,
hr,
html,
i,
iframe,
img,
ins,
kbd,
label,
legend,
li,
main,
mark,
menu,
meter,
nav,
object,
ol,
output,
p,
pre,
progress,
q,
rp,
rt,
ruby,
s,
samp,
section,
small,
span,
strike,
strong,
sub,
summary,
sup,
table,
tbody,
td,
tfoot,
th,
thead,
time,
tr,
tt,
u,
ul,
var,
video,
xmp {
  border: 0;
  margin: 0;
  padding: 0;
  font-size: 100%;
}

html,
body {
  height: 100%;
}

article,
aside,
details,
figcaption,
figure,
footer,
header,
hgroup,
main,
menu,
nav,
section,
summary {
	display: block;
}

audio,
canvas,
progress,
video {
	display: inline-block;
	vertical-align: baseline;
}

audio:not([controls]) {
	display: none;
	height: 0;
}

[hidden],
template {
	display: none;
}

a {
	background-color: transparent;
}

a:active,
a:hover {
	outline: 0;
}

abbr[title] {
	border-bottom: 1px dotted;
}

b,
strong {
	font-weight: bold;
}

dfn {
	font-style: italic;
}

h1 {
	font-size: 2em;
	margin: 0.67em 0;
}

mark {
	background: #444;
	color: #fff;
}

small {
	font-size: 80%;
}

sub,
sup {
	font-size: 75%;
	line-height: 0;
	position: relative;
	vertical-align: baseline;
}

sup {
	top: -0.5em;
}

sub {
	bottom: -0.25em;
}

img {
	border: 0;
	color: transparent;
	vertical-align: middle;
	-ms-interpolation-mode: bicubic;
}

ul,
ol {
  list-style: none;
}

li {
  display: list-item;
}

svg:not(:root) {
	overflow: hidden;
}

figure {
	margin: 1em 0px;
}

hr {
	box-sizing: content-box;
	height: 0;
}

pre {
	overflow: auto;
}

code,
kbd,
pre,
samp {
	font-family: monospace, monospace;
	font-size: 1em;
}

button,
input,
optgroup,
select,
textarea {
	color: inherit;
	font: inherit;
	margin: 0;
}

button {
	overflow: visible;
}

button,
select {
	text-transform: none;
}

button,
html input[type="button"],
input[type="reset"],
input[type="submit"] {
	-webkit-appearance: button;
	cursor: pointer;
}

button[disabled],
html input[disabled] {
	cursor: default;
}

button::-moz-focus-inner,
input::-moz-focus-inner {
	border: 0;
	padding: 0;
}

input {
	line-height: normal;
}

input[type="checkbox"],
input[type="radio"] {
	box-sizing: border-box;
	padding: 0;
}

input[type="number"]::-webkit-inner-spin-button,
input[type="number"]::-webkit-outer-spin-button {
	height: auto;
}

input[type="search"] {
	-webkit-appearance: textfield;
	box-sizing: content-box;
}

input[type="search"]::-webkit-search-cancel-button,
input[type="search"]::-webkit-search-decoration {
	-webkit-appearance: none;
}

fieldset {
	border: 1px solid #c0c0c0;
	margin: 0 2px;
	padding: 0.35em 0.625em 0.75em;
}

legend {
	border: 0;
	padding: 0;
}

textarea {
	overflow: auto;
}

optgroup {
	font-weight: bold;
}

table {
	border-collapse: collapse;
	border-spacing: 0;
}

td,
th {
	padding: 0;
}

th,
td,
caption {
  font-weight: normal;
  vertical-align: top;
  text-align: left;
}
/*--------------------------------------------------------------
2.0 Typography
--------------------------------------------------------------*/
body {
  font-family: Verdana, Geneva, sans-serif;
}

body,
button,
input,
select,
textarea {
	color: #999;
	font-size: 14px;
	line-height: 1.5;
}

h1 {
  font-size: 2em;
}

h2 {
  font-size: 1.28em;
}

h3 {
  font-size: 1.21em;
}

h4 {
  font-size: 1.14em;
}

h5 {
  font-size: 1.07em;
}

h6 {
  font-size: 1em;
}

h1,
h2,
h3,
h4,
h5,
h6 {
	font-family: 'Helvetica Neue', Helvetica, Arial, sans-serif;
	font-weight: 400;
	color: #eee;
	clear: both;
}

p {
	margin-bottom: 1.5em;
	text-align: left;
}

b,
strong {
	font-weight: bold;
}

dfn,
cite,
em,
i {
	font-style: italic;
}

blockquote {
	margin: 0 2em 1.5em 2em;
	padding: 1em 3em;
	background-color: transparent;
	position: relative;
}
blockquote p {margin-bottom: 0;}

address {
	margin: 0 0 1.5em;
}

pre {
	background: #333339;
	font-family: "Courier 10 Pitch", Courier, monospace;
	font-size: 1em;
	color: #fff;
	line-height: 1.6;
	margin-bottom: 1.6em;
	max-width: 100%;
	overflow: auto;
	padding: 1.6em;
}

code,
kbd,
tt,
var {
	font-family: Monaco, Consolas, "Andale Mono", "DejaVu Sans Mono", monospace;
	font-size: 1em;
}

abbr,
acronym {
	border-bottom: 1px dotted #666;
	cursor: help;
}

mark,
ins {
	background: #444;
	color: #fff;
	text-decoration: none;
}

small {
	font-size: 75%;
}

big {
	font-size: 125%;
}
.site-branding {
	text-align: center;
}
h1.site-title, h3.site-title {
	margin-top: 24px; 
	margin-bottom: 0;
	font-family: Georgia, serif;
	font-size: 38px; 
	font-weight: normal;
	line-height: 1.2;
	white-space: nowrap;
}
h1.site-title a, h3.site-title a {
	text-decoration: none;
}
h1.site-title a,
h1.site-title a:visited,
h1.site-title a:hover,
h1.site-title a:active,
h1.site-title a:focus,
h3.site-title a,
h3.site-title a:visited,
h3.site-title a:hover,
h3.site-title a:active,
h3.site-title a:focus {
	color: #eee;
}
h2.site-description, h4.site-description {
	margin-top: -25px; 
	margin-bottom: 10px;
	font-family: Verdana, Geneva, sans-serif;
	font-size: 16px;
	color: #999;
	font-weight: normal;
	line-height: 1.2;
	white-space: nowrap;
	letter-spacing: 0px;
}
.custom-logo {
	max-height: 100px;
	width: auto;
	height: auto;
}
/* Social nav */
#social1 {margin-top: 10px;}
.social-navigation {
	font-size: 14px;
	margin-bottom: 10px;
	text-align: center;
}

.social-navigation ul {
	list-style: none;
	margin-bottom: 0;
	margin-left: 0;
}

.social-navigation li {
	display: inline;
}

.social-navigation a {
	color: #000;
	display: inline-block;
	margin: 0 0 0 10px;
	text-align: center;
}

.social-navigation .fa {
	font-size: 26px;
	color: #888;
	line-height: 1.2;
}
/*--------------------------------------------------------------
3.0 Elements
--------------------------------------------------------------*/
html {
/*	box-sizing: border-box; */ 
}

*,
*:before,
*:after { /* Inherit box-sizing to make it easier to change the property for components that leverage other behavior; see http://css-tricks.com/inheriting-box-sizing-probably-slightly-better-best-practice/ */
	box-sizing: inherit;
}

body {
	background: #000; /* Fallback for when there is no custom background color defined. */
}

blockquote:before {
  content: "\f10d"; /*Unicode for Left Double Quote*/
  
  /*Font*/
  font-family: 'FontAwesome';
  font-style: italic;
  font-size: 2em;
  color: #444;
  
  /*Positioning*/
  position: absolute;
  left: 0px;
  top: 0;
}
blockquote:after {
  content: ""; 
}

q:before {
	content: open-quote;
}

q:after {
	content: close-quote;
}

blockquote {
	quotes: "" "";
}

q {
	quotes: """ """;
	font-style: italic;
}

hr {
	background-color: #444;
	border: 0;
	height: 1px;
	margin-bottom: 1.5em;
}

ul,
ol {
	margin: 0 0 1.5em 1.5em;
}

ul {
	list-style: disc;
}

ol {
	list-style: decimal;
}

li > ul,
li > ol {
	margin-bottom: 0;
	margin-left: 1.5em;
}

dt {
	font-weight: bold;
}

dd {
	margin: 0 1.5em 1.5em;
}

img {
	height: auto; /* Make sure images are scaled correctly. */
	max-width: 100%; /* Adhere to container width. */
}

table {
	margin: 0 0 1.5em;
	width: 100%;
}
table {
	overflow-x: auto;
	display: block;
}
table {
	border-width: 0px !important;
	border-spacing: 0px;
	border-style: solid;
	border-color: #777;
	border-collapse: collapse;
	background-color: transparent;
}
table th {
	border-width: 1px;
	padding: 3px 10px 3px 10px;
	border-style: solid;
	border-color: #777;
	background-color: transparent;
	text-align:left;
	color:#eee;
}
table td {
	border-width: 1px;
	padding: 3px 10px 3px 10px;
	border-style: solid;
	border-color: #777;
	background-color: transparent;
	text-align:left;
	color:#999;
}
/* empty elements */
.egrid {min-height: 1px !important;}
/* unsemantic  */

dl,
hr,
ol,
ul,
pre,
table,
address,
fieldset,
figure {
  margin-bottom: 20px;
}
h1,
h2,
h3,
h4,
h5,
h6 {
  margin-bottom: 0.6em;
}
h1.entry-title, h1.page-title {
	margin-bottom: 0.3em;
	margin-top: 0;
}
p {
  margin-bottom: 1em;
}
main#main {
	margin-bottom: 30px;
}
@media screen and (max-width: 768px) {
	.grid-container {
		padding-right: 5px !important;
		padding-left: 5px !important;
	}
}
/*--------------------------------------------------------------
4.0 Forms
--------------------------------------------------------------*/
.button,
button,
input[type="submit"],
input[type="reset"],
input[type="button"] {
	display: inline-block;
	height: auto;
	padding: 11px 20px;
	color: #fff;
	text-align: center;
	font-size: 14px;
	font-weight: 600;
	letter-spacing: 1px;
	text-transform: uppercase;
	text-decoration: none;
	white-space: nowrap;
	background-color: #444449;
	border-radius: 5px;
	border: 1px solid #55555a;
	cursor: pointer;
	box-sizing: border-box;
 }
  
.button:hover,
button:hover,
input[type="submit"]:hover,
input[type="reset"]:hover,
input[type="button"]:hover,
.button:focus,
button:focus,
input[type="submit"]:focus,
input[type="reset"]:focus,
input[type="button"]:focus,
button:active,
input[type="submit"]:active,
input[type="reset"]:active,
input[type="button"]:active {
  color: #fff;
  border-color: #55555a;
  background-color: #55555a;
  outline: 0; }

.button.button-primary,
button.button-primary,
input[type="submit"].button-primary,
input[type="reset"].button-primary,
input[type="button"].button-primary {
  color: #FFF;
  background-color: #33C3F0;
  border-color: #33C3F0; }

.button.button-primary:hover,
button.button-primary:hover,
input[type="submit"].button-primary:hover,
input[type="reset"].button-primary:hover,
input[type="button"].button-primary:hover,
.button.button-primary:focus,
button.button-primary:focus,
input[type="submit"].button-primary:focus,
input[type="reset"].button-primary:focus,
input[type="button"].button-primary:focus,
.button.button-primary:active,
button.button-primary:active,
input[type="submit"].button-primary:active,
input[type="reset"].button-primary:active,
input[type="button"].button-primary:active {
  color: #FFF;
  background-color: #1EAEDB;
  border-color: #1EAEDB; }

input[type="email"],
input[type="number"],
input[type="search"],
input[type="text"],
input[type="tel"],
input[type="url"],
input[type="password"],
textarea,
select {
  color: #bbb;
  height: 38px;
  padding: 6px 10px; /* The 6px vertically centers text on FF, ignored by Webkit */
  background-color: #333338;
  border: 1px solid #444449;
  border-radius: 4px;
  box-shadow: none;
  box-sizing: border-box; }

/* Removes awkward default styles on some inputs for iOS */
input[type="email"],
input[type="number"],
input[type="search"],
input[type="text"],
input[type="tel"],
input[type="url"],
input[type="password"],
textarea {
  -webkit-appearance: none;
     -moz-appearance: none;
          appearance: none; }
		  
textarea {
  min-height: 100px;
  padding-top: 6px;
  padding-bottom: 6px; }
  
input[type="email"]:focus,
input[type="number"]:focus,
input[type="search"]:focus,
input[type="text"]:focus,
input[type="tel"]:focus,
input[type="url"]:focus,
input[type="password"]:focus,
textarea:focus,
select:focus {
  border: 1px solid #55555a;
  outline: 0; }

textarea {
	width: 100%;
}

label,
legend {
  display: block;
  margin-bottom: 5px;
  font-weight: 600; }
  
fieldset {
  padding: 0;
  border-width: 0; }
  
input[type="checkbox"],
input[type="radio"] {
  display: inline; }
  
label > .label-body {
  display: inline-block;
  margin-left: 5px;
  font-weight: normal; }

/* search */
input[type="search"] {
  height: 38px;
  padding: 6px 10px; /* The 6px vertically centers text on FF, ignored by Webkit */
  background-color: transparent;
  border: 1px solid #666666;
  border-radius: 4px;
  box-shadow: none;
  box-sizing: border-box; 
  color: #aaa;
}
  
input[type="search"]:focus {
  border: 1px solid #777777;
  outline: 0; 
}
.widget_search {
	position:relative;
}
#search1 {
	position:relative;
	margin-top: 10px;
}
#search1 fieldset {
	margin-bottom: 0px;
}
.search-container {
	position:relative;
}
input.search-field {
	width:100%;
	position:relative;
	display:block;
	border-color: #666666;
	border-width: 1px;
}

input.search-field::-webkit-input-placeholder { /* WebKit browsers */
    color:    #555;
}
input.search-field:-moz-placeholder { /* Mozilla Firefox 4 to 18 */
   color:    #555;
   opacity:  1;
}
input.search-field::-moz-placeholder { /* Mozilla Firefox 19+ */
   color:    #555;
   opacity:  1;
}
input.search-field:-ms-input-placeholder { /* Internet Explorer 10+ */
   color:    #555;
}
input[type="submit"].search-submit {
	background-image: url(images/search32.png);
	background-size: 16px 16px;
	background-repeat: no-repeat;
	width:16px !important;
	height:16px !important;
	border:none;
	position:absolute;
	top:12px;
	right:10px;
	cursor:pointer;
	padding: 0 !important;
	background-color: transparent;
	border-radius: 0;
	border: 0px solid #bbb;
}  
.widget_search input[type="submit"].search-submit {
	background-image: url(images/search32.png);
	background-repeat: no-repeat;
	background-size: 16px 16px;
	width:16px !important;
	height:16px !important;
	border:none;
	position:absolute;
	top:12px;
	right:10px;
	cursor:pointer;
	padding: 0 !important;
	background-color: transparent;
	border-radius: 0;
	border: 0px solid #bbb;
	display: block;
}

/*--------------------------------------------------------------
5.0 Navigation
--------------------------------------------------------------*/
#breadcrumbs {padding-top: 10px; font-size: 0.9em;}
.breadcrumbs {padding: 10px 0 20px 0; font-size: 0.9em;}

/*--------------------------------------------------------------
5.1 Links
--------------------------------------------------------------*/
a {
	color: #eee;
	text-decoration: none;
}

a:visited {
	color: #eee;
	text-decoration: none;
}

a:hover,
a:focus,
a:active {
	color: #eee;
	text-decoration: underline;
}

a:focus {
	outline: 0;
	text-decoration: none;
}

a:hover,
a:active {
	outline: 0;
}

h1 a, h2 a, h3 a, h4 a, h5 a, h6 a {
	color: #eee !important;
}

h1 a:hover, h2 a:hover, h3 a:hover, h4 a:hover, h5 a:hover, h6 a:hover {
	color: #eee;
	text-decoration: none;
}

/*--------------------------------------------------------------
5.2 Menus
--------------------------------------------------------------*/
.main-navigation {
	clear: both;
	display: block;
	float: left;
	width: 100%;
	margin-top: 15px;
	margin-bottom: 0px;
}
#main-menu {
	position: relative;
	z-index: 200;
	border-top: 1px solid #444;
	border-bottom: 1px solid #444;
	margin-bottom: 1px;
}
#main-menu.collapsed {
    display: block;
}
/* Small menu. */
#menu-button {
	display: none;
}
#menu-button {
  background: none;
  color: #fff;
  line-height: 1.2;
  cursor: pointer;
  text-align: left;
  margin: 0;
  padding: 10px 12px;
  border: none;
  font-size: 26px;
  -moz-border-radius:0px;
  -webkit-border-radius:0px;
  border-radius:0px;
  width: 100%;
  border-top: 1px solid #444;
  border-bottom: 1px solid #444;
}
#menu-button span {
	font-family: Arial, Helvetica, sans-serif;
	padding-left: 5px;
}
@media screen and (max-width: 1023px) {

  /* show the button on small screens */
  #menu-button {
    display:inline-block;
  }
  /* hide the menu when it has the "collapsed" class set by the script */
  #main-menu.collapsed {
    display:none;
  }
  #main-menu {
	border-top: 0px dotted #444;
  }
}
@media screen and (min-width: 768px) {
  .site-branding {
	text-align: left;
  }
  #social1 {margin-top: 47px;}
  .social-navigation {
	text-align: right;
  }
}
/* Header widget horizontal custom menu - without dropdown */
#header-widget-1 aside.widget_nav_menu,
#header-widget-2 aside.widget_nav_menu {
	margin-bottom: 0;
	margin-top: 10px;
	text-align: right;
}
#header-widget-1 aside.widget_nav_menu ul,
#header-widget-2 aside.widget_nav_menu ul {
	margin: 0;
	padding: 0;
	list-style-type: none;
	text-transform: uppercase;
	font-size: 13px;
}
#header-widget-1 aside.widget_nav_menu ul,
#header-widget-2 aside.widget_nav_menu ul { 
	display: inline; 
}
#header-widget-1 aside.widget_nav_menu ul li,
#header-widget-2 aside.widget_nav_menu ul li {
	display: inline; 
}

#header-widget-1 aside.widget_nav_menu ul li a,
#header-widget-2 aside.widget_nav_menu ul li a {
	text-decoration: none;
	padding: 0 0.5em;
	color: #999;
	white-space: nowrap;
}

#header-widget-1 aside.widget_nav_menu ul li a:hover,
#header-widget-2 aside.widget_nav_menu ul li a:hover,
#header-widget-1 aside.widget_nav_menu ul li.current-menu-item a,
#header-widget-2 aside.widget_nav_menu ul li.current-menu-item a {
	color: #eee;
}

/* Navigation */
.site-main .comment-navigation,
.site-main .posts-navigation,
.site-main .post-navigation {
	margin: 0 0 1.5em;
	overflow: hidden;
}

.comment-navigation .nav-previous,
.posts-navigation .nav-previous,
.post-navigation .nav-previous {
	float: left;
	width: 47%;
	font-size: 0.85em;
	text-transform: uppercase;
}

.comment-navigation .nav-previous a:before,
.posts-navigation .nav-previous a:before,
.post-navigation .nav-previous a:before {
	-webkit-font-smoothing: antialiased;
	display: inline-block;
	font: normal 1.2em/1 FontAwesome;
	text-decoration: inherit;
	vertical-align: baseline;
	content: "\f0d9";
	margin-right: 7px;
}

.comment-navigation .nav-previous a,
.posts-navigation .nav-previous a,
.post-navigation .nav-previous a {
	color: #999;
}

.comment-navigation .nav-previous a:hover,
.posts-navigation .nav-previous a:hover,
.post-navigation .nav-previous a:hover {
	text-decoration: none;
	color: #eee;
}

.comment-navigation .nav-next,
.posts-navigation .nav-next,
.post-navigation .nav-next {
	float: right;
	text-align: right;
	width: 47%;
	font-size: 0.85em;
	text-transform: uppercase;
}

.comment-navigation .nav-next a:after,
.posts-navigation .nav-next a:after,
.post-navigation .nav-next a:after {
	-webkit-font-smoothing: antialiased;
	display: inline-block;
	font: normal 1.2em/1 FontAwesome;
	text-decoration: inherit;
	vertical-align: baseline;
	content: "\f0da";
	margin-left: 7px;
}

.comment-navigation .nav-next a,
.posts-navigation .nav-next a,
.post-navigation .nav-next a {
	color: #999;
}

.comment-navigation .nav-next a:hover,
.posts-navigation .nav-next a:hover,
.post-navigation .nav-next a:hover {
	text-decoration: none;
	color: #eee;
}

/*--------------------------------------------------------------
6.0 Accessibility
--------------------------------------------------------------*/
/* Text meant only for screen readers. */
.screen-reader-text {
	clip: rect(1px, 1px, 1px, 1px);
	position: absolute !important;
	height: 1px;
	width: 1px;
	overflow: hidden;
}

.screen-reader-text:hover,
.screen-reader-text:active,
.screen-reader-text:focus {
	background-color: #333;
	border-radius: 3px;
	box-shadow: 0 0 2px 2px rgba(0, 0, 0, 0.6);
	clip: auto !important;
	color: #fff;
	display: block;
	font-size: 14px;
	font-weight: bold;
	height: auto;
	left: 5px;
	line-height: normal;
	padding: 15px 23px 14px;
	text-decoration: none;
	top: 5px;
	width: auto;
	z-index: 100000; /* Above WP toolbar. */
}

/*--------------------------------------------------------------
7.0 Alignments
--------------------------------------------------------------*/
.alignleft {
	display: inline;
	float: left;
	margin-right: 15px;
}

.alignright {
	display: inline;
	float: right;
	margin-left: 15px;
}

.aligncenter {
	clear: both;
	display: block;
	margin-left: auto;
	margin-right: auto;
}

/*--------------------------------------------------------------
8.0 Clearings
--------------------------------------------------------------*/
.clear:before,
.clear:after,
.entry-content:before,
.entry-content:after,
.comment-content:before,
.comment-content:after,
.site-header:before,
.site-header:after,
.site-content:before,
.site-content:after,
.site-footer:before,
.site-footer:after {
	content: "";
	display: table;
}

.clear:after,
.entry-content:after,
.comment-content:after,
.site-header:after,
.site-content:after,
.site-footer:after {
	clear: both;
}

/*--------------------------------------------------------------
9.0 Widgets
--------------------------------------------------------------*/
.widget {
	margin: 0 0 2em;
}
.widget ul,
.widget ol {
	margin: 0 0 0 1.2em;
	list-style-position: outside;
}
.widget ul.children,
.widget ol.children {
	margin: 0 0 0 1.2em;
}
/* footer list and custom menu widgets */
.sepline {
	border-top: 1px solid #444;
	margin-bottom: 20px;
}
.sepline2 {
	border-top: 1px solid #444;
	margin-bottom: 10px;
}
/* Custom menu widget not in the footer */
#secondary .widget_nav_menu ul {
    list-style: outside none none;
    margin: 0;
    padding: 0;
}
#secondary .widget_nav_menu li {
    letter-spacing: 1px;
    margin: 0;
    padding: 5px 0 5px 0;
    text-transform: uppercase;
	border-bottom: 1px solid #444;
}
#secondary .widget_nav_menu li a {
    display: inline;
    padding: 0;
    text-decoration: none;
	color: #999;
}
html > body #secondary .widget_nav_menu li a {
    width: auto;
}
#secondary .widget_nav_menu li ul {
    font-size: 0.9em;
    list-style-position: outside;
    list-style-type: square;
	margin-left: 18px;
}
#secondary .widget_nav_menu li ul li {
    letter-spacing: 0;
    padding: 4px 0 2px 0;
    text-transform: none;
    background: none repeat scroll 0 0 rgba(0, 0, 0, 0);
    border-bottom: 0 solid #ccc;
    border-top: 0 dashed #e4e4e4;
}
#secondary .widget_nav_menu li ul li ul {
	font-size: 1em;
}

#secondary .widget_nav_menu li ul li a {
    display: inline;
    padding: 0;
    text-decoration: none;
	background: none repeat scroll 0 0 rgba(0, 0, 0, 0);
}
html > body #secondary .widget_nav_menu li ul li a {
    width: auto;
}
#secondary .widget_nav_menu {
    background: none repeat scroll 0 0 rgba(0, 0, 0, 0);
    border-bottom: 0 solid #fff;
    color: #999;
}
#secondary .widget_nav_menu ul li.current-menu-item a {
    color: #eee;
}
#secondary .widget_nav_menu ul li.current-menu-item * a {
    color: #999;
}
#secondary .widget_nav_menu li ul li a:hover, #secondary .widget_nav_menu li.current-menu-item ul li a:hover {
    background: none repeat scroll 0 0 rgba(0, 0, 0, 0);
    color: #eee;
}
#secondary .widget_nav_menu li a, #secondary .widget_nav_menu li a:visited {
    color: #999;
    text-decoration: none;
}
#secondary .widget_nav_menu li a:hover, #secondary .widget_nav_menu li a:focus {
    background: none repeat scroll 0 0 rgba(0, 0, 0, 0);
    color: #eee;
    text-decoration: none;
}
#secondary .widget_nav_menu li a:active {
    color: #eee;
    text-decoration: none;
}
/* Widget titles in the left and right sidebars */
#secondary h4.widget-title {
	font-weight: 700;
    text-transform: uppercase;
	border-bottom: 1px solid #444;
	font-size: 1.07em;
	padding-bottom: 4px;
	word-wrap: break-word;
}
#secondary .widget_nav_menu h4.widget-title {
	font-weight: 700;
	margin-bottom: 0;
	padding-bottom: 4px;
	word-wrap: break-word;
}
/* Make sure select elements fit in widgets. */
.widget select {
	max-width: 100%;
}

/* Search widget. */
.widget_search .search-submit {
	display: none;
}
/* Calendar widget. */
.widget_calendar table {
	display: table;
}
.widget_calendar table caption {
	text-align: center;
	color: #eee;
	margin-bottom: 5px;
	font-weight: bold;
}
.widget_calendar table,
.widget_calendar th,
.widget_calendar td {
	border-width: 0px;
}
.widget_calendar th,
.widget_calendar td {
	padding: 0;
	text-align: center;
}
.widget_calendar td#prev {
	text-align: left;
}
.widget_calendar td#next {
	text-align: right;
}
.widget_calendar th {
	background-color: transparent;
	font-weight: bold;
	color: #eee;
}
/* Featured posts widget */
.featured-posts .featured-item div a {
	font-size: 0.9em;
	line-height: 1.2;
}
.featured-posts .featured-item  {
	margin: 12px 0 0px 0;
	line-height: 1.2;
}
.featured-posts .featured-item div.featured-post-widget-image {
	display: inline;
	float: left;
	width: 55px;
	height: 55px;
	background: #ddd;
}
.featured-posts .featured-item div.featured-post-widget-content {
	margin-left: 65px;
}
.featured-posts .featured-item img  {
	margin: 0;
}
.featured-posts .featured-item div.entry-meta {
	font-size: 0.9em;
	line-height: 1.2;
	margin-top: 5px;
}
.featured-posts .featured-item div.entry-meta a {
	color: #888;
	font-size: 0.8em;
}
.featured-posts .featured-item div.entry-meta a:hover {
	text-decoration: none;
}
.featured-posts .featured-item2  {
	margin: 0;
}
.featured-item2:nth-child(n+2) {
	margin-top: 20px;
	padding-top: 15px;
	border-top: 1px solid #444;
}
.featured-posts .featured-item2 .featured-post-widget-content2  {
	line-height: 1.5;
}
.featured-posts .featured-item2 div h4.featured-post-widget-title2 {
	margin-top: 0px;
	margin-bottom: 3px;
	font-size: 1.14em;
	line-height: 1.5;
}
.featured-posts .featured-item2 .featured-post-widget-excerpt {
	margin-top: 3px;
	text-align: left;
}

.textwidget:after {
  content: "";
  display: table;
  clear: both;
}
.textwidget p {
	margin-bottom: 0;
}

/*--------------------------------------------------------------
10.0 Content
--------------------------------------------------------------*/
#myslideshow {
	margin-top: 0px;
	margin-bottom: 0px;
}
#content {
	padding-top: 30px;
}
.read-more {
  display: inline-block;
  font: normal normal normal 1em/1 FontAwesome;
  font-size: inherit;
  text-rendering: auto;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  transform: translate(0, 0);
}
.read-more:before {
  content: "\f101";
}
/*--------------------------------------------------------------
10.1 Posts and pages
--------------------------------------------------------------*/
.sticky {
	display: block;
}

.hentry {
	margin: 0 0 1.5em;
}

.blog .hentry {
	padding-bottom: 1.5em;
	margin: 0 0 1.5em;
	border-bottom: 1px dotted #444;
}

.byline,
.updated:not(.published) {
	display: none;
}

.single .byline,
.group-blog .byline {
	display: inline;
}

.page-content,
.entry-content {
	margin: 1.5em 0 0;
}
.entry-summary {
	margin: 0;
	font-weight: bold;
}
.search-entry-summary {
	margin-top: 1em;
}
.page-links {
	clear: both;
	margin: 1.5em 0 1.5em 0;
}

.entry-meta {
	font-size: 0.85em;
	text-transform: uppercase;
}

.entry-meta span.posted-on,
.entry-meta span.byline,
.entry-meta span.comments-link,
.comment-meta time {
	margin-right: 1em;
}

#comments .reply {
	margin-bottom: 1.5em;
}

.entry-footer {
	margin-top:10px;
}

.entry-footer span.cat-links,
.entry-footer span.tags-links,
.entry-footer span.update {
	font-size: 0.85em;
	text-transform: uppercase;
	font-weight: normal;
}

.entry-footer span.update {
	text-transform: uppercase;
}

.entry-footer span.cat-links {
	margin-right: 1em;
}

.entry-footer span.cat-links a,
.entry-footer span.tags-links a,
.entry-footer span.update a {
	font-weight: normal;
}
.entry-footer span.update a {
	color: #999;
	text-transform: none;
}

.entry-footer span.cat-links-label,
.entry-footer span.tags-links-label {
	font-size: 0.85em;
	text-transform: uppercase;
	font-weight: bold;
	margin-right: 0.8em;
	display: inline-block;
}

.entry-footer ul.post-categories,
.entry-footer ul.post-tags {
margin: 0;
padding: 0;
list-style-type: none;
text-align: center;
font-size: 0.85em;
text-transform: uppercase;
display: inline;
}

.entry-footer ul.post-categories li,
.entry-footer ul.post-tags li { 
display: inline-block; 
margin: 0 1em 0 0;
}

.entry-footer ul.post-categories li a,
.entry-footer ul.post-tags li a {
text-decoration: none;
}

.entry-footer ul.post-categories li a:hover,
.entry-footer ul.post-tags li a:hover {
text-decoration: underline;
}

#reply-title a#cancel-comment-reply-link, 
.attachment span.entry-date,
.entry-content .edit-link a,
.entry-footer .edit-link a,
.entry-meta .edit-link a,
.comment-meta .edit-link a,
.comment-metadata > a time,
.site-content .byline a,
.site-content .comments-link a,
.site-content .posted-on a {
	color: #999;
}

#reply-title a#cancel-comment-reply-link:hover, 
.attachment span.entry-date:hover,
.entry-content .edit-link a:hover,
.entry-footer .edit-link a:hover,
.entry-meta .edit-link a:hover,
.comment-meta .edit-link a:hover,
.comment-metadata > a time:hover,
.comment-metadata > a:hover,
.site-content .byline a:hover,
.site-content .comments-link a:hover,
.site-content .posted-on a:hover,
#comments .reply a:hover {
	color: #eee;
	text-decoration: none;
}

#reply-title a#cancel-comment-reply-link:before, 
.attachment span.entry-date:before,
.entry-content .edit-link a:before,
.entry-footer .edit-link a:before,
.entry-meta .edit-link a:before,
.comment-meta .edit-link a:before,
.site-content .byline a:before,
.site-content .comments-link a:before,
.site-content .posted-on a:before,
#comments .reply a:before {
	-webkit-font-smoothing: antialiased;
	display: inline-block;
	font: normal 1em/1 FontAwesome;
	text-decoration: inherit;
	vertical-align: baseline;
}

#reply-title a#cancel-comment-reply-link {
	float: right;
	height: 24px;
	overflow: hidden;
	width: 24px;
	color: #eee;
}
#reply-title a#cancel-comment-reply-link:hover {
	text-decoration: none;
}
#reply-title a#cancel-comment-reply-link:before {
	content: "\f00d";
	margin-right: 2px;
	font: normal 24px/1 FontAwesome;
}

.site-content .posted-on a:before,
.attachment .site-content span.entry-date:before {
		content: "\f017";
		margin-right: 2px;
}

.site-content .byline a:before {
		content: "\f007";
		margin-right: 2px;
}

.site-content .comments-link a:before {
		content: "\f075";
		margin-right: 2px;
}

.entry-content .edit-link a:before,
.entry-meta .edit-link a:before,
.entry-footer .edit-link a:before,
.comment-meta .edit-link a:before {
		content: "\f044";
		margin-right: 2px;
}

#comments .reply a:before {
		content: "\f112";
		margin-right: 2px;
}

.entry-meta .edit-link,
.entry-meta .byline,
.entry-meta .posted-on,
.entry-meta .comments-link {
	display: inline-block;
}

/*--------------------------------------------------------------
10.2 Asides
--------------------------------------------------------------*/
.blog .format-aside .entry-title,
.archive .format-aside .entry-title {
	display: none;
}

/*--------------------------------------------------------------
10.3 Comments
--------------------------------------------------------------*/
.comment-content a {
	word-wrap: break-word;
}

.bypostauthor {
	display: block;
}
#comments .comment-metadata {
	margin-bottom: 10px;
	font-size: 0.85em;
	text-transform: uppercase;
}
/*--------------------------------------------------------------
11.0 Infinite scroll
--------------------------------------------------------------*/
/* Globally hidden elements when Infinite Scroll is supported and in use. */
.infinite-scroll .posts-navigation, /* Older / Newer Posts Navigation (always hidden) */
.infinite-scroll.neverending .site-footer { /* Theme Footer (when set to scrolling) */
	display: none;
}

/* When Infinite Scroll has reached its end we need to re-display elements that were hidden (via .neverending) before. */
.infinity-end.neverending .site-footer {
	display: block;
}

/*--------------------------------------------------------------
12.0 Media
--------------------------------------------------------------*/
.page-content .wp-smiley,
.entry-content .wp-smiley,
.comment-content .wp-smiley {
	border: none;
	margin-bottom: 0;
	margin-top: 0;
	padding: 0;
}

/* Make sure embeds and iframes fit their containers. */
embed,
iframe,
object {
	max-width: 100%;
}
/* Featured image */
img.wp-post-image {
	margin-bottom: 5px;
	margin-top: 5px;
}
@media screen and (max-width: 480px) {
  .smallpostthumb {
	display: block;
	float: none;
	margin-right: 0px;
	width: 100%;
  }
}
.format-image img[class*="wp-image"] {
	clear: both;
    display: block;
    margin: 0 auto;	
}
/*--------------------------------------------------------------
12.1 Captions
--------------------------------------------------------------*/
.wp-caption {
	margin-bottom: 1em;
	max-width: 100%;
}

.wp-caption img[class*="wp-image-"] {
	display: block;
	margin: 0 auto;
}

.wp-caption-text {
	text-align: center;
	font-size: 0.9em;
}

.wp-caption .wp-caption-text {
	margin: 0.5em 0;
}

/*--------------------------------------------------------------
12.2 Galleries
--------------------------------------------------------------*/
.gallery {
    clear: both;
    display: block;
    margin: 1.5em auto;
}

.gallery-item {
	display: inline-block;
	text-align: center;
	vertical-align: top;
	width: 100%;
	margin-top: 1em;
	margin-bottom: 0;
}

.gallery-columns-2 .gallery-item {
	max-width: 50%;
}

.gallery-columns-3 .gallery-item {
	max-width: 33.33%;
}

.gallery-columns-4 .gallery-item {
	max-width: 25%;
}

.gallery-columns-5 .gallery-item {
	max-width: 20%;
}

.gallery-columns-6 .gallery-item {
	max-width: 16.66%;
}

.gallery-columns-7 .gallery-item {
	max-width: 14.28%;
}

.gallery-columns-8 .gallery-item {
	max-width: 12.5%;
}

.gallery-columns-9 .gallery-item {
	max-width: 11.11%;
}

.gallery-caption {
	display: block;
	font-size: 0.75em;
	margin-top: 0.1em;
}
a#designer {font-size: 12px; margin-bottom: 20px; color: #999;}
/*--------------------------------------------------------------
12.3 Slideshow
--------------------------------------------------------------*/
.theme-default .nivo-caption a {border-bottom: none !important;}
.theme-default .nivoSlider {border: 0px solid #eee !important;}
/*--------------------------------------------------------------
13.0 WP 5
--------------------------------------------------------------*/
#page {overflow-x: hidden;}
/* Subhead */
p.wp-block-subhead  {color: #999;}
.alignwide, .alignfull {width: 100%;}
/* List widths */
.wp-block-latest-posts.alignwide, 
.wp-block-latest-comments.alignwide,
.wp-block-categories-list.alignwide,
.wp-block-latest-posts.alignfull, 
.wp-block-latest-comments.alignfull,
.wp-block-categories-list.alignfull
{width: auto;}
/* Table  */
.wp-block-table.alignwide, .wp-block-table.alignfull {
display: table; 
width: 100%  !important;}
/* Gallery widget */
.gallery {
  margin: 4px -8px;
}
.gallery-item {
  padding: 8px;
	margin-top: 0px;
}
/* Quote */
blockquote p {
margin-bottom: 10px; 
font-family: "Times New Roman", Times, serif; 
font-size: 20px; 
font-style: italic;}
.wp-block-pullquote {
	border-top: 0;
	border-bottom: 0;
}
.wp-block-pullquote p {
font-family: "Times New Roman", Times, serif;
	text-align: center;
}
.wp-block-quote {
	border-left: 0 !important;
}
blockquote.wp-block-quote.is-large {
	margin: 0 2em 1.5em 2em;
	padding: 1em 3em;
	border-left: 0;
}
blockquote.wp-block-quote.is-large p {
	font-family: "Times New Roman", Times, serif;
}
/* Gallery block */
ul.wp-block-gallery {margin-left: 0;}

/* Full width */
@media (max-width: 767px) {
#primary .wp-block-image.alignfull,
#primary .wp-block-embed.alignfull,
#primary .wp-block-cover.alignfull,
#primary .wp-block-gallery.alignfull {
    margin-left: calc(50% - 50vw);
    margin-right: calc(50% - 50vw);
    width: auto;
	max-width: 100vw;
	}
}
@media (max-width: 1024px) {
#primary.tablet-grid-100 .wp-block-image.alignfull,
#primary.tablet-grid-100 .wp-block-embed.alignfull,
#primary.tablet-grid-100 .wp-block-cover.alignfull,
#primary.tablet-grid-100 .wp-block-gallery.alignfull {
    margin-left: calc(50% - 50vw);
    margin-right: calc(50% - 50vw);
    width: auto;
	max-width: 100vw;
	}
}
@media (min-width: 1025px) {
#primary.grid-100 .alignfull {
    margin-left: calc(50% - 50vw);
    margin-right: calc(50% - 50vw);
    width: auto;
	  max-width: 100vw;
	}
#primary.grid-100 .wp-block-columns.alignfull,
#primary.grid-100 .wp-block-audio.alignfull,
#primary.grid-100 .wp-block-table.alignfull,
#primary.grid-100 .wp-block-latest-posts.alignfull,
#primary.grid-100 .wp-block-categories.alignfull,
#primary.grid-100 .wp-block-pullquote.alignfull,
#primary.grid-100 .wp-block-latest-comments.alignfull {
	padding-left: 30px;
	padding-right: 30px;
}
#primary.grid-100 .wp-block-table.alignfull {
display: table; 
width: 96vw !important; 
margin-left: calc(50% - 48vw) !important; 
margin-right: calc(50% - 48vw) !important;}
}
.alignfull, .alignwide {
    clear: both;
}
/* Separator  */
.wp-block-separator {width: 20%; margin-left: 40%; margin-right: 40%; margin-top: 20px; }
.wp-block-separator.is-style-wide,
 .wp-block-separator.is-style-dots {
 width: 100%; 
 margin-left: 0; 
 margin-right: 0; }
.wp-block-separator.is-style-dots::before {color: #999;}
/* Button */
.wp-block-button__link {border-radius: 4px; font-size: 15px;  text-transform: uppercase; letter-spacing: 1px;}
.wp-block-button__link:visited,
.wp-block-button__link:link,
.wp-block-button__link:hover,
.wp-block-button__link:active,
.wp-block-button__link:focus
{color: #fff; text-decoration: none; }


/* Columns */
.wp-block-columns {
  display: flex;
}
.wp-block-column {
  flex: 1;
}
.wp-block-columns {
  margin: 20px 0;
}
.wp-block-column {
  margin: 0 20px !important;
}
.wp-block-column:first-child {
	margin-left: 0 !important;
}
.wp-block-column:last-child {
	margin-right: 0 !important;
}
@media (max-width: 767px) {
  .wp-block-columns {
    display: block;
  }
	.wp-block-column {
    margin: 20px 0 !important;
  }
}
/* Latest posts grid */
.wp-block-latest-posts.is-grid {margin-left: 0;}
/* caption */
.wp-block-image figcaption, .wp-block-audio figcaption, .wp-block-embed figcaption {color: #999; text-align: center;}
/* list margin */
ol.wp-block-latest-comments,
.wp-block-latest-posts.wp-block-latest-posts__list,
ul.wp-block-rss {
    margin-left: 0;
}
.wp-block-column {
    margin: 0 !important;
}
.wp-block-calendar table th {
    background: transparent;
}
.wp-block-separator {
    border-bottom: 0 ;
}
.wp-block-quote.is-large:not(.is-style-plain), .wp-block-quote.is-style-large:not(.is-style-plain) {
     padding: 1em 3em; 
}
.woocommerce #respond input#submit, .woocommerce a.button, .woocommerce button.button, .woocommerce input.button {
    font-size: 14px;
    margin: 0;
    line-height: 1;
    cursor: pointer;
    position: relative;
    text-decoration: none;
    overflow: visible;
    padding: 12px 20px;
    font-weight: 700;
    border-radius: 3px;
    left: auto;
    color: #fff;
    background-color: #222;
    border: 0;
    display: inline-block;
    background-image: none;
    box-shadow: none;
    text-shadow: none;
}

.woocommerce #respond input#submit:hover, .woocommerce a.button:hover, .woocommerce button.button:hover, .woocommerce input.button:hover {
    background-color: #444;
    text-decoration: none;
    background-image: none;
    color: #fff;
}
.woocommerce #respond input#submit.disabled, .woocommerce #respond input#submit:disabled, .woocommerce #respond input#submit:disabled[disabled], .woocommerce a.button.disabled, .woocommerce a.button:disabled, .woocommerce a.button:disabled[disabled], .woocommerce button.button.disabled, .woocommerce button.button:disabled, .woocommerce button.button:disabled[disabled], .woocommerce input.button.disabled, .woocommerce input.button:disabled, .woocommerce input.button:disabled[disabled] {
    padding: 12px 20px;
}
.woocommerce-error, .woocommerce-info, .woocommerce-message {
    padding: 1em 2em 1em 3.5em;
    margin: 0 0 2em;
    position: relative;
    background-color: #222;
    color: #eee;
    border-top: 3px solid #444;
    list-style: none outside;
    width: auto;
    word-wrap: break-word;
}
#add_payment_method #payment, .woocommerce-cart #payment, .woocommerce-checkout #payment {
    background: #111;
    border-radius: 5px;
}
.woocommerce form .form-row.woocommerce-invalid label {
    color: rgb(240, 89, 1);
}
.woocommerce div.product .woocommerce-tabs ul.tabs li {
    border: 1px solid #333;
    background-color: #111;
}
.woocommerce div.product .woocommerce-tabs ul.tabs li.active {
    background: #222;
    border-bottom-color: #222;
}
.woocommerce div.product .woocommerce-tabs ul.tabs::before {
    border-bottom: 1px solid #222;
}
.woocommerce div.product .woocommerce-tabs ul.tabs li a {
    color: #ccc;
}
.woocommerce div.product .woocommerce-tabs ul.tabs li a:hover {
    text-decoration: none;
    color: #eee;
}
.woocommerce div.product .woocommerce-tabs ul.tabs li.active a {
    color: #eee;
}
/*!
 *  Font Awesome 4.7.0 by @davegandy - http://fontawesome.io - @fontawesome
 *  License - http://fontawesome.io/license (Font: SIL OFL 1.1, CSS: MIT License)
 */
/* FONT PATH
 * -------------------------- */
@font-face {
  font-family: 'FontAwesome';
  src: url('fonts/fontawesome-webfont.eot?v=4.7.0');
  src: url('fonts/fontawesome-webfont.eot?#iefix&v=4.7.0') format('embedded-opentype'), url('fonts/fontawesome-webfont.woff2?v=4.7.0') format('woff2'), url('fonts/fontawesome-webfont.woff?v=4.7.0') format('woff'), url('fonts/fontawesome-webfont.ttf?v=4.7.0') format('truetype'), url('fonts/fontawesome-webfont.svg?v=4.7.0#fontawesomeregular') format('svg');
  font-weight: normal;
  font-style: normal;
}
.fa {
  display: inline-block;
  font: normal normal normal 14px/1 FontAwesome;
  font-size: inherit;
  text-rendering: auto;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
}
/* makes the font 33% larger relative to the icon container */
.fa-lg {
  font-size: 1.33333333em;
  line-height: 0.75em;
  vertical-align: -15%;
}
.fa-2x {
  font-size: 2em;
}
.fa-3x {
  font-size: 3em;
}
.fa-4x {
  font-size: 4em;
}
.fa-5x {
  font-size: 5em;
}
.fa-fw {
  width: 1.28571429em;
  text-align: center;
}
.fa-ul {
  padding-left: 0;
  margin-left: 2.14285714em;
  list-style-type: none;
}
.fa-ul > li {
  position: relative;
}
.fa-li {
  position: absolute;
  left: -2.14285714em;
  width: 2.14285714em;
  top: 0.14285714em;
  text-align: center;
}
.fa-li.fa-lg {
  left: -1.85714286em;
}
.fa-border {
  padding: .2em .25em .15em;
  border: solid 0.08em #eee;
  border-radius: .1em;
}
.fa-pull-left {
  float: left;
}
.fa-pull-right {
  float: right;
}
.fa.fa-pull-left {
  margin-right: .3em;
}
.fa.fa-pull-right {
  margin-left: .3em;
}
/* Deprecated as of 4.4.0 */
.pull-right {
  float: right;
}
.pull-left {
  float: left;
}
.fa.pull-left {
  margin-right: .3em;
}
.fa.pull-right {
  margin-left: .3em;
}
.fa-spin {
  -webkit-animation: fa-spin 2s infinite linear;
  animation: fa-spin 2s infinite linear;
}
.fa-pulse {
  -webkit-animation: fa-spin 1s infinite steps(8);
  animation: fa-spin 1s infinite steps(8);
}
@-webkit-keyframes fa-spin {
  0% {
    -webkit-transform: rotate(0deg);
    transform: rotate(0deg);
  }
  100% {
    -webkit-transform: rotate(359deg);
    transform: rotate(359deg);
  }
}
@keyframes fa-spin {
  0% {
    -webkit-transform: rotate(0deg);
    transform: rotate(0deg);
  }
  100% {
    -webkit-transform: rotate(359deg);
    transform: rotate(359deg);
  }
}
.fa-rotate-90 {
  -ms-filter: "progid:DXImageTransform.Microsoft.BasicImage(rotation=1)";
  -webkit-transform: rotate(90deg);
  -ms-transform: rotate(90deg);
  transform: rotate(90deg);
}
.fa-rotate-180 {
  -ms-filter: "progid:DXImageTransform.Microsoft.BasicImage(rotation=2)";
  -webkit-transform: rotate(180deg);
  -ms-transform: rotate(180deg);
  transform: rotate(180deg);
}
.fa-rotate-270 {
  -ms-filter: "progid:DXImageTransform.Microsoft.BasicImage(rotation=3)";
  -webkit-transform: rotate(270deg);
  -ms-transform: rotate(270deg);
  transform: rotate(270deg);
}
.fa-flip-horizontal {
  -ms-filter: "progid:DXImageTransform.Microsoft.BasicImage(rotation=0, mirror=1)";
  -webkit-transform: scale(-1, 1);
  -ms-transform: scale(-1, 1);
  transform: scale(-1, 1);
}
.fa-flip-vertical {
  -ms-filter: "progid:DXImageTransform.Microsoft.BasicImage(rotation=2, mirror=1)";
  -webkit-transform: scale(1, -1);
  -ms-transform: scale(1, -1);
  transform: scale(1, -1);
}
:root .fa-rotate-90,
:root .fa-rotate-180,
:root .fa-rotate-270,
:root .fa-flip-horizontal,
:root .fa-flip-vertical {
  filter: none;
}
.fa-stack {
  position: relative;
  display: inline-block;
  width: 2em;
  height: 2em;
  line-height: 2em;
  vertical-align: middle;
}
.fa-stack-1x,
.fa-stack-2x {
  position: absolute;
  left: 0;
  width: 100%;
  text-align: center;
}
.fa-stack-1x {
  line-height: inherit;
}
.fa-stack-2x {
  font-size: 2em;
}
.fa-inverse {
  color: #fff;
}
/* Font Awesome uses the Unicode Private Use Area (PUA) to ensure screen
   readers do not read off random characters that represent icons */
.fa-glass:before {
  content: "\f000";
}
.fa-music:before {
  content: "\f001";
}
.fa-search:before {
  content: "\f002";
}
.fa-envelope-o:before {
  content: "\f003";
}
.fa-heart:before {
  content: "\f004";
}
.fa-star:before {
  content: "\f005";
}
.fa-star-o:before {
  content: "\f006";
}
.fa-user:before {
  content: "\f007";
}
.fa-film:before {
  content: "\f008";
}
.fa-th-large:before {
  content: "\f009";
}
.fa-th:before {
  content: "\f00a";
}
.fa-th-list:before {
  content: "\f00b";
}
.fa-check:before {
  content: "\f00c";
}
.fa-remove:before,
.fa-close:before,
.fa-times:before {
  content: "\f00d";
}
.fa-search-plus:before {
  content: "\f00e";
}
.fa-search-minus:before {
  content: "\f010";
}
.fa-power-off:before {
  content: "\f011";
}
.fa-signal:before {
  content: "\f012";
}
.fa-gear:before,
.fa-cog:before {
  content: "\f013";
}
.fa-trash-o:before {
  content: "\f014";
}
.fa-home:before {
  content: "\f015";
}
.fa-file-o:before {
  content: "\f016";
}
.fa-clock-o:before {
  content: "\f017";
}
.fa-road:before {
  content: "\f018";
}
.fa-download:before {
  content: "\f019";
}
.fa-arrow-circle-o-down:before {
  content: "\f01a";
}
.fa-arrow-circle-o-up:before {
  content: "\f01b";
}
.fa-inbox:before {
  content: "\f01c";
}
.fa-play-circle-o:before {
  content: "\f01d";
}
.fa-rotate-right:before,
.fa-repeat:before {
  content: "\f01e";
}
.fa-refresh:before {
  content: "\f021";
}
.fa-list-alt:before {
  content: "\f022";
}
.fa-lock:before {
  content: "\f023";
}
.fa-flag:before {
  content: "\f024";
}
.fa-headphones:before {
  content: "\f025";
}
.fa-volume-off:before {
  content: "\f026";
}
.fa-volume-down:before {
  content: "\f027";
}
.fa-volume-up:before {
  content: "\f028";
}
.fa-qrcode:before {
  content: "\f029";
}
.fa-barcode:before {
  content: "\f02a";
}
.fa-tag:before {
  content: "\f02b";
}
.fa-tags:before {
  content: "\f02c";
}
.fa-book:before {
  content: "\f02d";
}
.fa-bookmark:before {
  content: "\f02e";
}
.fa-print:before {
  content: "\f02f";
}
.fa-camera:before {
  content: "\f030";
}
.fa-font:before {
  content: "\f031";
}
.fa-bold:before {
  content: "\f032";
}
.fa-italic:before {
  content: "\f033";
}
.fa-text-height:before {
  content: "\f034";
}
.fa-text-width:before {
  content: "\f035";
}
.fa-align-left:before {
  content: "\f036";
}
.fa-align-center:before {
  content: "\f037";
}
.fa-align-right:before {
  content: "\f038";
}
.fa-align-justify:before {
  content: "\f039";
}
.fa-list:before {
  content: "\f03a";
}
.fa-dedent:before,
.fa-outdent:before {
  content: "\f03b";
}
.fa-indent:before {
  content: "\f03c";
}
.fa-video-camera:before {
  content: "\f03d";
}
.fa-photo:before,
.fa-image:before,
.fa-picture-o:before {
  content: "\f03e";
}
.fa-pencil:before {
  content: "\f040";
}
.fa-map-marker:before {
  content: "\f041";
}
.fa-adjust:before {
  content: "\f042";
}
.fa-tint:before {
  content: "\f043";
}
.fa-edit:before,
.fa-pencil-square-o:before {
  content: "\f044";
}
.fa-share-square-o:before {
  content: "\f045";
}
.fa-check-square-o:before {
  content: "\f046";
}
.fa-arrows:before {
  content: "\f047";
}
.fa-step-backward:before {
  content: "\f048";
}
.fa-fast-backward:before {
  content: "\f049";
}
.fa-backward:before {
  content: "\f04a";
}
.fa-play:before {
  content: "\f04b";
}
.fa-pause:before {
  content: "\f04c";
}
.fa-stop:before {
  content: "\f04d";
}
.fa-forward:before {
  content: "\f04e";
}
.fa-fast-forward:before {
  content: "\f050";
}
.fa-step-forward:before {
  content: "\f051";
}
.fa-eject:before {
  content: "\f052";
}
.fa-chevron-left:before {
  content: "\f053";
}
.fa-chevron-right:before {
  content: "\f054";
}
.fa-plus-circle:before {
  content: "\f055";
}
.fa-minus-circle:before {
  content: "\f056";
}
.fa-times-circle:before {
  content: "\f057";
}
.fa-check-circle:before {
  content: "\f058";
}
.fa-question-circle:before {
  content: "\f059";
}
.fa-info-circle:before {
  content: "\f05a";
}
.fa-crosshairs:before {
  content: "\f05b";
}
.fa-times-circle-o:before {
  content: "\f05c";
}
.fa-check-circle-o:before {
  content: "\f05d";
}
.fa-ban:before {
  content: "\f05e";
}
.fa-arrow-left:before {
  content: "\f060";
}
.fa-arrow-right:before {
  content: "\f061";
}
.fa-arrow-up:before {
  content: "\f062";
}
.fa-arrow-down:before {
  content: "\f063";
}
.fa-mail-forward:before,
.fa-share:before {
  content: "\f064";
}
.fa-expand:before {
  content: "\f065";
}
.fa-compress:before {
  content: "\f066";
}
.fa-plus:before {
  content: "\f067";
}
.fa-minus:before {
  content: "\f068";
}
.fa-asterisk:before {
  content: "\f069";
}
.fa-exclamation-circle:before {
  content: "\f06a";
}
.fa-gift:before {
  content: "\f06b";
}
.fa-leaf:before {
  content: "\f06c";
}
.fa-fire:before {
  content: "\f06d";
}
.fa-eye:before {
  content: "\f06e";
}
.fa-eye-slash:before {
  content: "\f070";
}
.fa-warning:before,
.fa-exclamation-triangle:before {
  content: "\f071";
}
.fa-plane:before {
  content: "\f072";
}
.fa-calendar:before {
  content: "\f073";
}
.fa-random:before {
  content: "\f074";
}
.fa-comment:before {
  content: "\f075";
}
.fa-magnet:before {
  content: "\f076";
}
.fa-chevron-up:before {
  content: "\f077";
}
.fa-chevron-down:before {
  content: "\f078";
}
.fa-retweet:before {
  content: "\f079";
}
.fa-shopping-cart:before {
  content: "\f07a";
}
.fa-folder:before {
  content: "\f07b";
}
.fa-folder-open:before {
  content: "\f07c";
}
.fa-arrows-v:before {
  content: "\f07d";
}
.fa-arrows-h:before {
  content: "\f07e";
}
.fa-bar-chart-o:before,
.fa-bar-chart:before {
  content: "\f080";
}
.fa-twitter-square:before {
  content: "\f081";
}
.fa-facebook-square:before {
  content: "\f082";
}
.fa-camera-retro:before {
  content: "\f083";
}
.fa-key:before {
  content: "\f084";
}
.fa-gears:before,
.fa-cogs:before {
  content: "\f085";
}
.fa-comments:before {
  content: "\f086";
}
.fa-thumbs-o-up:before {
  content: "\f087";
}
.fa-thumbs-o-down:before {
  content: "\f088";
}
.fa-star-half:before {
  content: "\f089";
}
.fa-heart-o:before {
  content: "\f08a";
}
.fa-sign-out:before {
  content: "\f08b";
}
.fa-linkedin-square:before {
  content: "\f08c";
}
.fa-thumb-tack:before {
  content: "\f08d";
}
.fa-external-link:before {
  content: "\f08e";
}
.fa-sign-in:before {
  content: "\f090";
}
.fa-trophy:before {
  content: "\f091";
}
.fa-github-square:before {
  content: "\f092";
}
.fa-upload:before {
  content: "\f093";
}
.fa-lemon-o:before {
  content: "\f094";
}
.fa-phone:before {
  content: "\f095";
}
.fa-square-o:before {
  content: "\f096";
}
.fa-bookmark-o:before {
  content: "\f097";
}
.fa-phone-square:before {
  content: "\f098";
}
.fa-twitter:before {
  content: "\f099";
}
.fa-facebook-f:before,
.fa-facebook:before {
  content: "\f09a";
}
.fa-github:before {
  content: "\f09b";
}
.fa-unlock:before {
  content: "\f09c";
}
.fa-credit-card:before {
  content: "\f09d";
}
.fa-feed:before,
.fa-rss:before {
  content: "\f09e";
}
.fa-hdd-o:before {
  content: "\f0a0";
}
.fa-bullhorn:before {
  content: "\f0a1";
}
.fa-bell:before {
  content: "\f0f3";
}
.fa-certificate:before {
  content: "\f0a3";
}
.fa-hand-o-right:before {
  content: "\f0a4";
}
.fa-hand-o-left:before {
  content: "\f0a5";
}
.fa-hand-o-up:before {
  content: "\f0a6";
}
.fa-hand-o-down:before {
  content: "\f0a7";
}
.fa-arrow-circle-left:before {
  content: "\f0a8";
}
.fa-arrow-circle-right:before {
  content: "\f0a9";
}
.fa-arrow-circle-up:before {
  content: "\f0aa";
}
.fa-arrow-circle-down:before {
  content: "\f0ab";
}
.fa-globe:before {
  content: "\f0ac";
}
.fa-wrench:before {
  content: "\f0ad";
}
.fa-tasks:before {
  content: "\f0ae";
}
.fa-filter:before {
  content: "\f0b0";
}
.fa-briefcase:before {
  content: "\f0b1";
}
.fa-arrows-alt:before {
  content: "\f0b2";
}
.fa-group:before,
.fa-users:before {
  content: "\f0c0";
}
.fa-chain:before,
.fa-link:before {
  content: "\f0c1";
}
.fa-cloud:before {
  content: "\f0c2";
}
.fa-flask:before {
  content: "\f0c3";
}
.fa-cut:before,
.fa-scissors:before {
  content: "\f0c4";
}
.fa-copy:before,
.fa-files-o:before {
  content: "\f0c5";
}
.fa-paperclip:before {
  content: "\f0c6";
}
.fa-save:before,
.fa-floppy-o:before {
  content: "\f0c7";
}
.fa-square:before {
  content: "\f0c8";
}
.fa-navicon:before,
.fa-reorder:before,
.fa-bars:before {
  content: "\f0c9";
}
.fa-list-ul:before {
  content: "\f0ca";
}
.fa-list-ol:before {
  content: "\f0cb";
}
.fa-strikethrough:before {
  content: "\f0cc";
}
.fa-underline:before {
  content: "\f0cd";
}
.fa-table:before {
  content: "\f0ce";
}
.fa-magic:before {
  content: "\f0d0";
}
.fa-truck:before {
  content: "\f0d1";
}
.fa-pinterest:before {
  content: "\f0d2";
}
.fa-pinterest-square:before {
  content: "\f0d3";
}
.fa-google-plus-square:before {
  content: "\f0d4";
}
.fa-google-plus:before {
  content: "\f0d5";
}
.fa-money:before {
  content: "\f0d6";
}
.fa-caret-down:before {
  content: "\f0d7";
}
.fa-caret-up:before {
  content: "\f0d8";
}
.fa-caret-left:before {
  content: "\f0d9";
}
.fa-caret-right:before {
  content: "\f0da";
}
.fa-columns:before {
  content: "\f0db";
}
.fa-unsorted:before,
.fa-sort:before {
  content: "\f0dc";
}
.fa-sort-down:before,
.fa-sort-desc:before {
  content: "\f0dd";
}
.fa-sort-up:before,
.fa-sort-asc:before {
  content: "\f0de";
}
.fa-envelope:before {
  content: "\f0e0";
}
.fa-linkedin:before {
  content: "\f0e1";
}
.fa-rotate-left:before,
.fa-undo:before {
  content: "\f0e2";
}
.fa-legal:before,
.fa-gavel:before {
  content: "\f0e3";
}
.fa-dashboard:before,
.fa-tachometer:before {
  content: "\f0e4";
}
.fa-comment-o:before {
  content: "\f0e5";
}
.fa-comments-o:before {
  content: "\f0e6";
}
.fa-flash:before,
.fa-bolt:before {
  content: "\f0e7";
}
.fa-sitemap:before {
  content: "\f0e8";
}
.fa-umbrella:before {
  content: "\f0e9";
}
.fa-paste:before,
.fa-clipboard:before {
  content: "\f0ea";
}
.fa-lightbulb-o:before {
  content: "\f0eb";
}
.fa-exchange:before {
  content: "\f0ec";
}
.fa-cloud-download:before {
  content: "\f0ed";
}
.fa-cloud-upload:before {
  content: "\f0ee";
}
.fa-user-md:before {
  content: "\f0f0";
}
.fa-stethoscope:before {
  content: "\f0f1";
}
.fa-suitcase:before {
  content: "\f0f2";
}
.fa-bell-o:before {
  content: "\f0a2";
}
.fa-coffee:before {
  content: "\f0f4";
}
.fa-cutlery:before {
  content: "\f0f5";
}
.fa-file-text-o:before {
  content: "\f0f6";
}
.fa-building-o:before {
  content: "\f0f7";
}
.fa-hospital-o:before {
  content: "\f0f8";
}
.fa-ambulance:before {
  content: "\f0f9";
}
.fa-medkit:before {
  content: "\f0fa";
}
.fa-fighter-jet:before {
  content: "\f0fb";
}
.fa-beer:before {
  content: "\f0fc";
}
.fa-h-square:before {
  content: "\f0fd";
}
.fa-plus-square:before {
  content: "\f0fe";
}
.fa-angle-double-left:before {
  content: "\f100";
}
.fa-angle-double-right:before {
  content: "\f101";
}
.fa-angle-double-up:before {
  content: "\f102";
}
.fa-angle-double-down:before {
  content: "\f103";
}
.fa-angle-left:before {
  content: "\f104";
}
.fa-angle-right:before {
  content: "\f105";
}
.fa-angle-up:before {
  content: "\f106";
}
.fa-angle-down:before {
  content: "\f107";
}
.fa-desktop:before {
  content: "\f108";
}
.fa-laptop:before {
  content: "\f109";
}
.fa-tablet:before {
  content: "\f10a";
}
.fa-mobile-phone:before,
.fa-mobile:before {
  content: "\f10b";
}
.fa-circle-o:before {
  content: "\f10c";
}
.fa-quote-left:before {
  content: "\f10d";
}
.fa-quote-right:before {
  content: "\f10e";
}
.fa-spinner:before {
  content: "\f110";
}
.fa-circle:before {
  content: "\f111";
}
.fa-mail-reply:before,
.fa-reply:before {
  content: "\f112";
}
.fa-github-alt:before {
  content: "\f113";
}
.fa-folder-o:before {
  content: "\f114";
}
.fa-folder-open-o:before {
  content: "\f115";
}
.fa-smile-o:before {
  content: "\f118";
}
.fa-frown-o:before {
  content: "\f119";
}
.fa-meh-o:before {
  content: "\f11a";
}
.fa-gamepad:before {
  content: "\f11b";
}
.fa-keyboard-o:before {
  content: "\f11c";
}
.fa-flag-o:before {
  content: "\f11d";
}
.fa-flag-checkered:before {
  content: "\f11e";
}
.fa-terminal:before {
  content: "\f120";
}
.fa-code:before {
  content: "\f121";
}
.fa-mail-reply-all:before,
.fa-reply-all:before {
  content: "\f122";
}
.fa-star-half-empty:before,
.fa-star-half-full:before,
.fa-star-half-o:before {
  content: "\f123";
}
.fa-location-arrow:before {
  content: "\f124";
}
.fa-crop:before {
  content: "\f125";
}
.fa-code-fork:before {
  content: "\f126";
}
.fa-unlink:before,
.fa-chain-broken:before {
  content: "\f127";
}
.fa-question:before {
  content: "\f128";
}
.fa-info:before {
  content: "\f129";
}
.fa-exclamation:before {
  content: "\f12a";
}
.fa-superscript:before {
  content: "\f12b";
}
.fa-subscript:before {
  content: "\f12c";
}
.fa-eraser:before {
  content: "\f12d";
}
.fa-puzzle-piece:before {
  content: "\f12e";
}
.fa-microphone:before {
  content: "\f130";
}
.fa-microphone-slash:before {
  content: "\f131";
}
.fa-shield:before {
  content: "\f132";
}
.fa-calendar-o:before {
  content: "\f133";
}
.fa-fire-extinguisher:before {
  content: "\f134";
}
.fa-rocket:before {
  content: "\f135";
}
.fa-maxcdn:before {
  content: "\f136";
}
.fa-chevron-circle-left:before {
  content: "\f137";
}
.fa-chevron-circle-right:before {
  content: "\f138";
}
.fa-chevron-circle-up:before {
  content: "\f139";
}
.fa-chevron-circle-down:before {
  content: "\f13a";
}
.fa-html5:before {
  content: "\f13b";
}
.fa-css3:before {
  content: "\f13c";
}
.fa-anchor:before {
  content: "\f13d";
}
.fa-unlock-alt:before {
  content: "\f13e";
}
.fa-bullseye:before {
  content: "\f140";
}
.fa-ellipsis-h:before {
  content: "\f141";
}
.fa-ellipsis-v:before {
  content: "\f142";
}
.fa-rss-square:before {
  content: "\f143";
}
.fa-play-circle:before {
  content: "\f144";
}
.fa-ticket:before {
  content: "\f145";
}
.fa-minus-square:before {
  content: "\f146";
}
.fa-minus-square-o:before {
  content: "\f147";
}
.fa-level-up:before {
  content: "\f148";
}
.fa-level-down:before {
  content: "\f149";
}
.fa-check-square:before {
  content: "\f14a";
}
.fa-pencil-square:before {
  content: "\f14b";
}
.fa-external-link-square:before {
  content: "\f14c";
}
.fa-share-square:before {
  content: "\f14d";
}
.fa-compass:before {
  content: "\f14e";
}
.fa-toggle-down:before,
.fa-caret-square-o-down:before {
  content: "\f150";
}
.fa-toggle-up:before,
.fa-caret-square-o-up:before {
  content: "\f151";
}
.fa-toggle-right:before,
.fa-caret-square-o-right:before {
  content: "\f152";
}
.fa-euro:before,
.fa-eur:before {
  content: "\f153";
}
.fa-gbp:before {
  content: "\f154";
}
.fa-dollar:before,
.fa-usd:before {
  content: "\f155";
}
.fa-rupee:before,
.fa-inr:before {
  content: "\f156";
}
.fa-cny:before,
.fa-rmb:before,
.fa-yen:before,
.fa-jpy:before {
  content: "\f157";
}
.fa-ruble:before,
.fa-rouble:before,
.fa-rub:before {
  content: "\f158";
}
.fa-won:before,
.fa-krw:before {
  content: "\f159";
}
.fa-bitcoin:before,
.fa-btc:before {
  content: "\f15a";
}
.fa-file:before {
  content: "\f15b";
}
.fa-file-text:before {
  content: "\f15c";
}
.fa-sort-alpha-asc:before {
  content: "\f15d";
}
.fa-sort-alpha-desc:before {
  content: "\f15e";
}
.fa-sort-amount-asc:before {
  content: "\f160";
}
.fa-sort-amount-desc:before {
  content: "\f161";
}
.fa-sort-numeric-asc:before {
  content: "\f162";
}
.fa-sort-numeric-desc:before {
  content: "\f163";
}
.fa-thumbs-up:before {
  content: "\f164";
}
.fa-thumbs-down:before {
  content: "\f165";
}
.fa-youtube-square:before {
  content: "\f166";
}
.fa-youtube:before {
  content: "\f167";
}
.fa-xing:before {
  content: "\f168";
}
.fa-xing-square:before {
  content: "\f169";
}
.fa-youtube-play:before {
  content: "\f16a";
}
.fa-dropbox:before {
  content: "\f16b";
}
.fa-stack-overflow:before {
  content: "\f16c";
}
.fa-instagram:before {
  content: "\f16d";
}
.fa-flickr:before {
  content: "\f16e";
}
.fa-adn:before {
  content: "\f170";
}
.fa-bitbucket:before {
  content: "\f171";
}
.fa-bitbucket-square:before {
  content: "\f172";
}
.fa-tumblr:before {
  content: "\f173";
}
.fa-tumblr-square:before {
  content: "\f174";
}
.fa-long-arrow-down:before {
  content: "\f175";
}
.fa-long-arrow-up:before {
  content: "\f176";
}
.fa-long-arrow-left:before {
  content: "\f177";
}
.fa-long-arrow-right:before {
  content: "\f178";
}
.fa-apple:before {
  content: "\f179";
}
.fa-windows:before {
  content: "\f17a";
}
.fa-android:before {
  content: "\f17b";
}
.fa-linux:before {
  content: "\f17c";
}
.fa-dribbble:before {
  content: "\f17d";
}
.fa-skype:before {
  content: "\f17e";
}
.fa-foursquare:before {
  content: "\f180";
}
.fa-trello:before {
  content: "\f181";
}
.fa-female:before {
  content: "\f182";
}
.fa-male:before {
  content: "\f183";
}
.fa-gittip:before,
.fa-gratipay:before {
  content: "\f184";
}
.fa-sun-o:before {
  content: "\f185";
}
.fa-moon-o:before {
  content: "\f186";
}
.fa-archive:before {
  content: "\f187";
}
.fa-bug:before {
  content: "\f188";
}
.fa-vk:before {
  content: "\f189";
}
.fa-weibo:before {
  content: "\f18a";
}
.fa-renren:before {
  content: "\f18b";
}
.fa-pagelines:before {
  content: "\f18c";
}
.fa-stack-exchange:before {
  content: "\f18d";
}
.fa-arrow-circle-o-right:before {
  content: "\f18e";
}
.fa-arrow-circle-o-left:before {
  content: "\f190";
}
.fa-toggle-left:before,
.fa-caret-square-o-left:before {
  content: "\f191";
}
.fa-dot-circle-o:before {
  content: "\f192";
}
.fa-wheelchair:before {
  content: "\f193";
}
.fa-vimeo-square:before {
  content: "\f194";
}
.fa-turkish-lira:before,
.fa-try:before {
  content: "\f195";
}
.fa-plus-square-o:before {
  content: "\f196";
}
.fa-space-shuttle:before {
  content: "\f197";
}
.fa-slack:before {
  content: "\f198";
}
.fa-envelope-square:before {
  content: "\f199";
}
.fa-wordpress:before {
  content: "\f19a";
}
.fa-openid:before {
  content: "\f19b";
}
.fa-institution:before,
.fa-bank:before,
.fa-university:before {
  content: "\f19c";
}
.fa-mortar-board:before,
.fa-graduation-cap:before {
  content: "\f19d";
}
.fa-yahoo:before {
  content: "\f19e";
}
.fa-google:before {
  content: "\f1a0";
}
.fa-reddit:before {
  content: "\f1a1";
}
.fa-reddit-square:before {
  content: "\f1a2";
}
.fa-stumbleupon-circle:before {
  content: "\f1a3";
}
.fa-stumbleupon:before {
  content: "\f1a4";
}
.fa-delicious:before {
  content: "\f1a5";
}
.fa-digg:before {
  content: "\f1a6";
}
.fa-pied-piper-pp:before {
  content: "\f1a7";
}
.fa-pied-piper-alt:before {
  content: "\f1a8";
}
.fa-drupal:before {
  content: "\f1a9";
}
.fa-joomla:before {
  content: "\f1aa";
}
.fa-language:before {
  content: "\f1ab";
}
.fa-fax:before {
  content: "\f1ac";
}
.fa-building:before {
  content: "\f1ad";
}
.fa-child:before {
  content: "\f1ae";
}
.fa-paw:before {
  content: "\f1b0";
}
.fa-spoon:before {
  content: "\f1b1";
}
.fa-cube:before {
  content: "\f1b2";
}
.fa-cubes:before {
  content: "\f1b3";
}
.fa-behance:before {
  content: "\f1b4";
}
.fa-behance-square:before {
  content: "\f1b5";
}
.fa-steam:before {
  content: "\f1b6";
}
.fa-steam-square:before {
  content: "\f1b7";
}
.fa-recycle:before {
  content: "\f1b8";
}
.fa-automobile:before,
.fa-car:before {
  content: "\f1b9";
}
.fa-cab:before,
.fa-taxi:before {
  content: "\f1ba";
}
.fa-tree:before {
  content: "\f1bb";
}
.fa-spotify:before {
  content: "\f1bc";
}
.fa-deviantart:before {
  content: "\f1bd";
}
.fa-soundcloud:before {
  content: "\f1be";
}
.fa-database:before {
  content: "\f1c0";
}
.fa-file-pdf-o:before {
  content: "\f1c1";
}
.fa-file-word-o:before {
  content: "\f1c2";
}
.fa-file-excel-o:before {
  content: "\f1c3";
}
.fa-file-powerpoint-o:before {
  content: "\f1c4";
}
.fa-file-photo-o:before,
.fa-file-picture-o:before,
.fa-file-image-o:before {
  content: "\f1c5";
}
.fa-file-zip-o:before,
.fa-file-archive-o:before {
  content: "\f1c6";
}
.fa-file-sound-o:before,
.fa-file-audio-o:before {
  content: "\f1c7";
}
.fa-file-movie-o:before,
.fa-file-video-o:before {
  content: "\f1c8";
}
.fa-file-code-o:before {
  content: "\f1c9";
}
.fa-vine:before {
  content: "\f1ca";
}
.fa-codepen:before {
  content: "\f1cb";
}
.fa-jsfiddle:before {
  content: "\f1cc";
}
.fa-life-bouy:before,
.fa-life-buoy:before,
.fa-life-saver:before,
.fa-support:before,
.fa-life-ring:before {
  content: "\f1cd";
}
.fa-circle-o-notch:before {
  content: "\f1ce";
}
.fa-ra:before,
.fa-resistance:before,
.fa-rebel:before {
  content: "\f1d0";
}
.fa-ge:before,
.fa-empire:before {
  content: "\f1d1";
}
.fa-git-square:before {
  content: "\f1d2";
}
.fa-git:before {
  content: "\f1d3";
}
.fa-y-combinator-square:before,
.fa-yc-square:before,
.fa-hacker-news:before {
  content: "\f1d4";
}
.fa-tencent-weibo:before {
  content: "\f1d5";
}
.fa-qq:before {
  content: "\f1d6";
}
.fa-wechat:before,
.fa-weixin:before {
  content: "\f1d7";
}
.fa-send:before,
.fa-paper-plane:before {
  content: "\f1d8";
}
.fa-send-o:before,
.fa-paper-plane-o:before {
  content: "\f1d9";
}
.fa-history:before {
  content: "\f1da";
}
.fa-circle-thin:before {
  content: "\f1db";
}
.fa-header:before {
  content: "\f1dc";
}
.fa-paragraph:before {
  content: "\f1dd";
}
.fa-sliders:before {
  content: "\f1de";
}
.fa-share-alt:before {
  content: "\f1e0";
}
.fa-share-alt-square:before {
  content: "\f1e1";
}
.fa-bomb:before {
  content: "\f1e2";
}
.fa-soccer-ball-o:before,
.fa-futbol-o:before {
  content: "\f1e3";
}
.fa-tty:before {
  content: "\f1e4";
}
.fa-binoculars:before {
  content: "\f1e5";
}
.fa-plug:before {
  content: "\f1e6";
}
.fa-slideshare:before {
  content: "\f1e7";
}
.fa-twitch:before {
  content: "\f1e8";
}
.fa-yelp:before {
  content: "\f1e9";
}
.fa-newspaper-o:before {
  content: "\f1ea";
}
.fa-wifi:before {
  content: "\f1eb";
}
.fa-calculator:before {
  content: "\f1ec";
}
.fa-paypal:before {
  content: "\f1ed";
}
.fa-google-wallet:before {
  content: "\f1ee";
}
.fa-cc-visa:before {
  content: "\f1f0";
}
.fa-cc-mastercard:before {
  content: "\f1f1";
}
.fa-cc-discover:before {
  content: "\f1f2";
}
.fa-cc-amex:before {
  content: "\f1f3";
}
.fa-cc-paypal:before {
  content: "\f1f4";
}
.fa-cc-stripe:before {
  content: "\f1f5";
}
.fa-bell-slash:before {
  content: "\f1f6";
}
.fa-bell-slash-o:before {
  content: "\f1f7";
}
.fa-trash:before {
  content: "\f1f8";
}
.fa-copyright:before {
  content: "\f1f9";
}
.fa-at:before {
  content: "\f1fa";
}
.fa-eyedropper:before {
  content: "\f1fb";
}
.fa-paint-brush:before {
  content: "\f1fc";
}
.fa-birthday-cake:before {
  content: "\f1fd";
}
.fa-area-chart:before {
  content: "\f1fe";
}
.fa-pie-chart:before {
  content: "\f200";
}
.fa-line-chart:before {
  content: "\f201";
}
.fa-lastfm:before {
  content: "\f202";
}
.fa-lastfm-square:before {
  content: "\f203";
}
.fa-toggle-off:before {
  content: "\f204";
}
.fa-toggle-on:before {
  content: "\f205";
}
.fa-bicycle:before {
  content: "\f206";
}
.fa-bus:before {
  content: "\f207";
}
.fa-ioxhost:before {
  content: "\f208";
}
.fa-angellist:before {
  content: "\f209";
}
.fa-cc:before {
  content: "\f20a";
}
.fa-shekel:before,
.fa-sheqel:before,
.fa-ils:before {
  content: "\f20b";
}
.fa-meanpath:before {
  content: "\f20c";
}
.fa-buysellads:before {
  content: "\f20d";
}
.fa-connectdevelop:before {
  content: "\f20e";
}
.fa-dashcube:before {
  content: "\f210";
}
.fa-forumbee:before {
  content: "\f211";
}
.fa-leanpub:before {
  content: "\f212";
}
.fa-sellsy:before {
  content: "\f213";
}
.fa-shirtsinbulk:before {
  content: "\f214";
}
.fa-simplybuilt:before {
  content: "\f215";
}
.fa-skyatlas:before {
  content: "\f216";
}
.fa-cart-plus:before {
  content: "\f217";
}
.fa-cart-arrow-down:before {
  content: "\f218";
}
.fa-diamond:before {
  content: "\f219";
}
.fa-ship:before {
  content: "\f21a";
}
.fa-user-secret:before {
  content: "\f21b";
}
.fa-motorcycle:before {
  content: "\f21c";
}
.fa-street-view:before {
  content: "\f21d";
}
.fa-heartbeat:before {
  content: "\f21e";
}
.fa-venus:before {
  content: "\f221";
}
.fa-mars:before {
  content: "\f222";
}
.fa-mercury:before {
  content: "\f223";
}
.fa-intersex:before,
.fa-transgender:before {
  content: "\f224";
}
.fa-transgender-alt:before {
  content: "\f225";
}
.fa-venus-double:before {
  content: "\f226";
}
.fa-mars-double:before {
  content: "\f227";
}
.fa-venus-mars:before {
  content: "\f228";
}
.fa-mars-stroke:before {
  content: "\f229";
}
.fa-mars-stroke-v:before {
  content: "\f22a";
}
.fa-mars-stroke-h:before {
  content: "\f22b";
}
.fa-neuter:before {
  content: "\f22c";
}
.fa-genderless:before {
  content: "\f22d";
}
.fa-facebook-official:before {
  content: "\f230";
}
.fa-pinterest-p:before {
  content: "\f231";
}
.fa-whatsapp:before {
  content: "\f232";
}
.fa-server:before {
  content: "\f233";
}
.fa-user-plus:before {
  content: "\f234";
}
.fa-user-times:before {
  content: "\f235";
}
.fa-hotel:before,
.fa-bed:before {
  content: "\f236";
}
.fa-viacoin:before {
  content: "\f237";
}
.fa-train:before {
  content: "\f238";
}
.fa-subway:before {
  content: "\f239";
}
.fa-medium:before {
  content: "\f23a";
}
.fa-yc:before,
.fa-y-combinator:before {
  content: "\f23b";
}
.fa-optin-monster:before {
  content: "\f23c";
}
.fa-opencart:before {
  content: "\f23d";
}
.fa-expeditedssl:before {
  content: "\f23e";
}
.fa-battery-4:before,
.fa-battery:before,
.fa-battery-full:before {
  content: "\f240";
}
.fa-battery-3:before,
.fa-battery-three-quarters:before {
  content: "\f241";
}
.fa-battery-2:before,
.fa-battery-half:before {
  content: "\f242";
}
.fa-battery-1:before,
.fa-battery-quarter:before {
  content: "\f243";
}
.fa-battery-0:before,
.fa-battery-empty:before {
  content: "\f244";
}
.fa-mouse-pointer:before {
  content: "\f245";
}
.fa-i-cursor:before {
  content: "\f246";
}
.fa-object-group:before {
  content: "\f247";
}
.fa-object-ungroup:before {
  content: "\f248";
}
.fa-sticky-note:before {
  content: "\f249";
}
.fa-sticky-note-o:before {
  content: "\f24a";
}
.fa-cc-jcb:before {
  content: "\f24b";
}
.fa-cc-diners-club:before {
  content: "\f24c";
}
.fa-clone:before {
  content: "\f24d";
}
.fa-balance-scale:before {
  content: "\f24e";
}
.fa-hourglass-o:before {
  content: "\f250";
}
.fa-hourglass-1:before,
.fa-hourglass-start:before {
  content: "\f251";
}
.fa-hourglass-2:before,
.fa-hourglass-half:before {
  content: "\f252";
}
.fa-hourglass-3:before,
.fa-hourglass-end:before {
  content: "\f253";
}
.fa-hourglass:before {
  content: "\f254";
}
.fa-hand-grab-o:before,
.fa-hand-rock-o:before {
  content: "\f255";
}
.fa-hand-stop-o:before,
.fa-hand-paper-o:before {
  content: "\f256";
}
.fa-hand-scissors-o:before {
  content: "\f257";
}
.fa-hand-lizard-o:before {
  content: "\f258";
}
.fa-hand-spock-o:before {
  content: "\f259";
}
.fa-hand-pointer-o:before {
  content: "\f25a";
}
.fa-hand-peace-o:before {
  content: "\f25b";
}
.fa-trademark:before {
  content: "\f25c";
}
.fa-registered:before {
  content: "\f25d";
}
.fa-creative-commons:before {
  content: "\f25e";
}
.fa-gg:before {
  content: "\f260";
}
.fa-gg-circle:before {
  content: "\f261";
}
.fa-tripadvisor:before {
  content: "\f262";
}
.fa-odnoklassniki:before {
  content: "\f263";
}
.fa-odnoklassniki-square:before {
  content: "\f264";
}
.fa-get-pocket:before {
  content: "\f265";
}
.fa-wikipedia-w:before {
  content: "\f266";
}
.fa-safari:before {
  content: "\f267";
}
.fa-chrome:before {
  content: "\f268";
}
.fa-firefox:before {
  content: "\f269";
}
.fa-opera:before {
  content: "\f26a";
}
.fa-internet-explorer:before {
  content: "\f26b";
}
.fa-tv:before,
.fa-television:before {
  content: "\f26c";
}
.fa-contao:before {
  content: "\f26d";
}
.fa-500px:before {
  content: "\f26e";
}
.fa-amazon:before {
  content: "\f270";
}
.fa-calendar-plus-o:before {
  content: "\f271";
}
.fa-calendar-minus-o:before {
  content: "\f272";
}
.fa-calendar-times-o:before {
  content: "\f273";
}
.fa-calendar-check-o:before {
  content: "\f274";
}
.fa-industry:before {
  content: "\f275";
}
.fa-map-pin:before {
  content: "\f276";
}
.fa-map-signs:before {
  content: "\f277";
}
.fa-map-o:before {
  content: "\f278";
}
.fa-map:before {
  content: "\f279";
}
.fa-commenting:before {
  content: "\f27a";
}
.fa-commenting-o:before {
  content: "\f27b";
}
.fa-houzz:before {
  content: "\f27c";
}
.fa-vimeo:before {
  content: "\f27d";
}
.fa-black-tie:before {
  content: "\f27e";
}
.fa-fonticons:before {
  content: "\f280";
}
.fa-reddit-alien:before {
  content: "\f281";
}
.fa-edge:before {
  content: "\f282";
}
.fa-credit-card-alt:before {
  content: "\f283";
}
.fa-codiepie:before {
  content: "\f284";
}
.fa-modx:before {
  content: "\f285";
}
.fa-fort-awesome:before {
  content: "\f286";
}
.fa-usb:before {
  content: "\f287";
}
.fa-product-hunt:before {
  content: "\f288";
}
.fa-mixcloud:before {
  content: "\f289";
}
.fa-scribd:before {
  content: "\f28a";
}
.fa-pause-circle:before {
  content: "\f28b";
}
.fa-pause-circle-o:before {
  content: "\f28c";
}
.fa-stop-circle:before {
  content: "\f28d";
}
.fa-stop-circle-o:before {
  content: "\f28e";
}
.fa-shopping-bag:before {
  content: "\f290";
}
.fa-shopping-basket:before {
  content: "\f291";
}
.fa-hashtag:before {
  content: "\f292";
}
.fa-bluetooth:before {
  content: "\f293";
}
.fa-bluetooth-b:before {
  content: "\f294";
}
.fa-percent:before {
  content: "\f295";
}
.fa-gitlab:before {
  content: "\f296";
}
.fa-wpbeginner:before {
  content: "\f297";
}
.fa-wpforms:before {
  content: "\f298";
}
.fa-envira:before {
  content: "\f299";
}
.fa-universal-access:before {
  content: "\f29a";
}
.fa-wheelchair-alt:before {
  content: "\f29b";
}
.fa-question-circle-o:before {
  content: "\f29c";
}
.fa-blind:before {
  content: "\f29d";
}
.fa-audio-description:before {
  content: "\f29e";
}
.fa-volume-control-phone:before {
  content: "\f2a0";
}
.fa-braille:before {
  content: "\f2a1";
}
.fa-assistive-listening-systems:before {
  content: "\f2a2";
}
.fa-asl-interpreting:before,
.fa-american-sign-language-interpreting:before {
  content: "\f2a3";
}
.fa-deafness:before,
.fa-hard-of-hearing:before,
.fa-deaf:before {
  content: "\f2a4";
}
.fa-glide:before {
  content: "\f2a5";
}
.fa-glide-g:before {
  content: "\f2a6";
}
.fa-signing:before,
.fa-sign-language:before {
  content: "\f2a7";
}
.fa-low-vision:before {
  content: "\f2a8";
}
.fa-viadeo:before {
  content: "\f2a9";
}
.fa-viadeo-square:before {
  content: "\f2aa";
}
.fa-snapchat:before {
  content: "\f2ab";
}
.fa-snapchat-ghost:before {
  content: "\f2ac";
}
.fa-snapchat-square:before {
  content: "\f2ad";
}
.fa-pied-piper:before {
  content: "\f2ae";
}
.fa-first-order:before {
  content: "\f2b0";
}
.fa-yoast:before {
  content: "\f2b1";
}
.fa-themeisle:before {
  content: "\f2b2";
}
.fa-google-plus-circle:before,
.fa-google-plus-official:before {
  content: "\f2b3";
}
.fa-fa:before,
.fa-font-awesome:before {
  content: "\f2b4";
}
.fa-handshake-o:before {
  content: "\f2b5";
}
.fa-envelope-open:before {
  content: "\f2b6";
}
.fa-envelope-open-o:before {
  content: "\f2b7";
}
.fa-linode:before {
  content: "\f2b8";
}
.fa-address-book:before {
  content: "\f2b9";
}
.fa-address-book-o:before {
  content: "\f2ba";
}
.fa-vcard:before,
.fa-address-card:before {
  content: "\f2bb";
}
.fa-vcard-o:before,
.fa-address-card-o:before {
  content: "\f2bc";
}
.fa-user-circle:before {
  content: "\f2bd";
}
.fa-user-circle-o:before {
  content: "\f2be";
}
.fa-user-o:before {
  content: "\f2c0";
}
.fa-id-badge:before {
  content: "\f2c1";
}
.fa-drivers-license:before,
.fa-id-card:before {
  content: "\f2c2";
}
.fa-drivers-license-o:before,
.fa-id-card-o:before {
  content: "\f2c3";
}
.fa-quora:before {
  content: "\f2c4";
}
.fa-free-code-camp:before {
  content: "\f2c5";
}
.fa-telegram:before {
  content: "\f2c6";
}
.fa-thermometer-4:before,
.fa-thermometer:before,
.fa-thermometer-full:before {
  content: "\f2c7";
}
.fa-thermometer-3:before,
.fa-thermometer-three-quarters:before {
  content: "\f2c8";
}
.fa-thermometer-2:before,
.fa-thermometer-half:before {
  content: "\f2c9";
}
.fa-thermometer-1:before,
.fa-thermometer-quarter:before {
  content: "\f2ca";
}
.fa-thermometer-0:before,
.fa-thermometer-empty:before {
  content: "\f2cb";
}
.fa-shower:before {
  content: "\f2cc";
}
.fa-bathtub:before,
.fa-s15:before,
.fa-bath:before {
  content: "\f2cd";
}
.fa-podcast:before {
  content: "\f2ce";
}
.fa-window-maximize:before {
  content: "\f2d0";
}
.fa-window-minimize:before {
  content: "\f2d1";
}
.fa-window-restore:before {
  content: "\f2d2";
}
.fa-times-rectangle:before,
.fa-window-close:before {
  content: "\f2d3";
}
.fa-times-rectangle-o:before,
.fa-window-close-o:before {
  content: "\f2d4";
}
.fa-bandcamp:before {
  content: "\f2d5";
}
.fa-grav:before {
  content: "\f2d6";
}
.fa-etsy:before {
  content: "\f2d7";
}
.fa-imdb:before {
  content: "\f2d8";
}
.fa-ravelry:before {
  content: "\f2d9";
}
.fa-eercast:before {
  content: "\f2da";
}
.fa-microchip:before {
  content: "\f2db";
}
.fa-snowflake-o:before {
  content: "\f2dc";
}
.fa-superpowers:before {
  content: "\f2dd";
}
.fa-wpexplorer:before {
  content: "\f2de";
}
.fa-meetup:before {
  content: "\f2e0";
}
.sr-only {
  position: absolute;
  width: 1px;
  height: 1px;
  padding: 0;
  margin: -1px;
  overflow: hidden;
  clip: rect(0, 0, 0, 0);
  border: 0;
}
.sr-only-focusable:active,
.sr-only-focusable:focus {
  position: static;
  width: auto;
  height: auto;
  margin: 0;
  overflow: visible;
  clip: auto;
}

/*
 * jQuery Nivo Slider v3.2
 * http://nivo.dev7studios.com
 *
 * Copyright 2012, Dev7studios
 * Free to use and abuse under the MIT license.
 * http://www.opensource.org/licenses/mit-license.php
 */
 
/* The Nivo Slider styles */
.nivoSlider {
	position:relative;
	width:100%;
	height:auto;
	overflow: hidden;
}
.nivoSlider img {
	position:absolute;
	top:0px;
	left:0px;
	max-width: none;
}
.nivo-main-image {
	display: block !important;
	position: relative !important; 
	width: 100% !important;
}

/* If an image is wrapped in a link */
.nivoSlider a.nivo-imageLink {
	position:absolute;
	top:0px;
	left:0px;
	width:100%;
	height:100%;
	border:0;
	padding:0;
	margin:0;
	z-index:6;
	display:none;
	background:white; 
	filter:alpha(opacity=0); 
	opacity:0;
}
/* The slices and boxes in the Slider */
.nivo-slice {
	display:block;
	position:absolute;
	z-index:5;
	height:100%;
	top:0;
}
.nivo-box {
	display:block;
	position:absolute;
	z-index:5;
	overflow:hidden;
}
.nivo-box img { display:block; }

/* Caption styles */
.nivo-caption {
	position:absolute;
	left:0px;
	bottom:0px;
	background:#000;
	color:#fff;
	width:100%;
	z-index:8;
	padding: 5px 10px;
	opacity: 0.8;
	overflow: hidden;
	display: none;
	-moz-opacity: 0.8;
	filter:alpha(opacity=8);
	-webkit-box-sizing: border-box; /* Safari/Chrome, other WebKit */
	-moz-box-sizing: border-box;    /* Firefox, other Gecko */
	box-sizing: border-box;         /* Opera/IE 8+ */
}
.nivo-caption p {
	padding:5px;
	margin:0;
}
.nivo-caption a {
	display:inline !important;
}
.nivo-html-caption {
    display:none;
}
/* Direction nav styles (e.g. Next & Prev) */
.nivo-directionNav a {
	position:absolute;
	top:45%;
	z-index:9;
	cursor:pointer;
}
.nivo-prevNav {
	left:0px;
}
.nivo-nextNav {
	right:0px;
}
/* Control nav styles (e.g. 1,2,3...) */
.nivo-controlNav {
	text-align:center;
	padding: 15px 0;
}
.nivo-controlNav a {
	cursor:pointer;
}
.nivo-controlNav a.active {
	font-weight:bold;
}
/*
Skin Name: Nivo Slider Default Theme
Skin URI: http://nivo.dev7studios.com
Description: The default skin for the Nivo Slider.
Version: 1.3
Author: Gilbert Pellegrom
Author URI: http://dev7studios.com
Supports Thumbs: true
*/

.theme-default .nivoSlider {
	position:relative;
	background:#fff url(images/loading.gif) no-repeat 50% 50%;
    margin-bottom:10px;
    -webkit-box-shadow: none;
    -moz-box-shadow: none;
    box-shadow: none;
}
.theme-default .nivoSlider img {
	position:absolute;
	top:0px;
	left:0px;
	display:none;
}
.theme-default .nivoSlider a {
	border:0;
	display:block;
}

.theme-default .nivo-controlNav {
	text-align: center;
	padding: 20px 0;
}
.theme-default .nivo-controlNav a {
	display:inline-block;
	width:22px;
	height:22px;
	background:url(images/bullets.png) no-repeat;
	text-indent:-9999px;
	border:0;
	margin: 0 2px;
}
.theme-default .nivo-controlNav a.active {
	background-position:0 -22px;
}

.theme-default .nivo-directionNav a {
	display:block;
	width:30px;
	height:30px;
	background:url(images/arrows.png) no-repeat;
	text-indent:-9999px;
	border:0;
	opacity: 0;
	-webkit-transition: all 200ms ease-in-out;
    -moz-transition: all 200ms ease-in-out;
    -o-transition: all 200ms ease-in-out;
    transition: all 200ms ease-in-out;
}
.theme-default:hover .nivo-directionNav a { opacity: 1; }
.theme-default a.nivo-nextNav {
	background-position:-30px 0;
	right:15px;
}
.theme-default a.nivo-prevNav {
	left:15px;
}

.theme-default .nivo-caption {
    font-family: Helvetica, Arial, sans-serif;
}
.theme-default .nivo-caption a {
    color:#fff;
    border-bottom:1px dotted #fff;
}
.theme-default .nivo-caption a:hover {
    color:#fff;
}

.theme-default .nivo-controlNav.nivo-thumbs-enabled {
	width: 100%;
}
.theme-default .nivo-controlNav.nivo-thumbs-enabled a {
	width: auto;
	height: auto;
	background: none;
	margin-bottom: 5px;
}
.theme-default .nivo-controlNav.nivo-thumbs-enabled img {
	display: block;
	width: 120px;
	height: auto;
}
/* Mobile first layout SmartMenus Core CSS (it's not recommended editing these rules)
   You need this once per page no matter how many menu trees or different themes you use.
-------------------------------------------------------------------------------------------*/

.sm,.sm ul,.sm li{display:block;list-style:none;margin:0;padding:0;line-height:normal;direction:ltr;-webkit-tap-highlight-color:rgba(0,0,0,0);}
.sm-rtl,.sm-rtl ul,.sm-rtl li{direction:rtl;text-align:right;}
.sm>li>h1,.sm>li>h2,.sm>li>h3,.sm>li>h4,.sm>li>h5,.sm>li>h6{margin:0;padding:0;}
.sm ul{display:none;}
.sm li,.sm a{position:relative;}
.sm a{display:block;}
.sm a.disabled{cursor:not-allowed;}
.sm:after{content:"\00a0";display:block;height:0;font:0px/0 serif;clear:both;visibility:hidden;overflow:hidden;}
.sm,.sm *,.sm *:before,.sm *:after{-moz-box-sizing:border-box;-webkit-box-sizing:border-box;box-sizing:border-box;}
.sm-clean {
  background: transparent;
  -webkit-border-radius: 0px;
  -moz-border-radius: 0px;
  -ms-border-radius: 0px;
  -o-border-radius: 0px;
  border-radius: 0px;
}
.sm-clean a, .sm-clean a:hover, .sm-clean a:focus, .sm-clean a:active {
  padding: 13px 20px;
  /* make room for the toggle button (sub indicator) */
  padding-right: 58px;
  color: #eee;
  font-family: Arial, Helvetica, sans-serif;
  font-size: 18px;
  font-weight: normal;
  line-height: 22px;
  text-decoration: none;
  text-transform: uppercase;
}
.sm-clean a {
  color: #999;
}
.sm-clean a.current {
  color: #eee;
}
.sm-clean a.disabled {
  color: #555;
}
.sm-clean a span.sub-arrow {
  position: absolute;
  top: 50%;
  margin-top: -17px;
  left: auto;
  right: 4px;
  width: 34px;
  height: 34px;
  overflow: hidden;
  font: bold 16px/34px monospace !important;
  text-align: center;
  text-shadow: none;
  background: rgba(170, 170, 170, 0.3);
  -webkit-border-radius: 5px;
  -moz-border-radius: 5px;
  -ms-border-radius: 5px;
  -o-border-radius: 5px;
  border-radius: 5px;
}
.sm-clean a.highlighted span.sub-arrow:before {
  display: block;
  content: '-';
}
.sm-clean > li:first-child > a, .sm-clean > li:first-child > :not(ul) a {
  -webkit-border-radius: 5px 5px 0 0;
  -moz-border-radius: 5px 5px 0 0;
  -ms-border-radius: 5px 5px 0 0;
  -o-border-radius: 5px 5px 0 0;
  border-radius: 5px 5px 0 0;
}
.sm-clean > li:last-child > a, .sm-clean > li:last-child > *:not(ul) a, .sm-clean > li:last-child > ul,
.sm-clean > li:last-child > ul > li:last-child > a, .sm-clean > li:last-child > ul > li:last-child > *:not(ul) a, .sm-clean > li:last-child > ul > li:last-child > ul,
.sm-clean > li:last-child > ul > li:last-child > ul > li:last-child > a, .sm-clean > li:last-child > ul > li:last-child > ul > li:last-child > *:not(ul) a, .sm-clean > li:last-child > ul > li:last-child > ul > li:last-child > ul,
.sm-clean > li:last-child > ul > li:last-child > ul > li:last-child > ul > li:last-child > a, .sm-clean > li:last-child > ul > li:last-child > ul > li:last-child > ul > li:last-child > *:not(ul) a, .sm-clean > li:last-child > ul > li:last-child > ul > li:last-child > ul > li:last-child > ul,
.sm-clean > li:last-child > ul > li:last-child > ul > li:last-child > ul > li:last-child > ul > li:last-child > a, .sm-clean > li:last-child > ul > li:last-child > ul > li:last-child > ul > li:last-child > ul > li:last-child > *:not(ul) a, .sm-clean > li:last-child > ul > li:last-child > ul > li:last-child > ul > li:last-child > ul > li:last-child > ul {
  -webkit-border-radius: 0 0 5px 5px;
  -moz-border-radius: 0 0 5px 5px;
  -ms-border-radius: 0 0 5px 5px;
  -o-border-radius: 0 0 5px 5px;
  border-radius: 0 0 5px 5px;
}
.sm-clean > li:last-child > a.highlighted, .sm-clean > li:last-child > *:not(ul) a.highlighted,
.sm-clean > li:last-child > ul > li:last-child > a.highlighted, .sm-clean > li:last-child > ul > li:last-child > *:not(ul) a.highlighted,
.sm-clean > li:last-child > ul > li:last-child > ul > li:last-child > a.highlighted, .sm-clean > li:last-child > ul > li:last-child > ul > li:last-child > *:not(ul) a.highlighted,
.sm-clean > li:last-child > ul > li:last-child > ul > li:last-child > ul > li:last-child > a.highlighted, .sm-clean > li:last-child > ul > li:last-child > ul > li:last-child > ul > li:last-child > *:not(ul) a.highlighted,
.sm-clean > li:last-child > ul > li:last-child > ul > li:last-child > ul > li:last-child > ul > li:last-child > a.highlighted, .sm-clean > li:last-child > ul > li:last-child > ul > li:last-child > ul > li:last-child > ul > li:last-child > *:not(ul) a.highlighted {
  -webkit-border-radius: 0;
  -moz-border-radius: 0;
  -ms-border-radius: 0;
  -o-border-radius: 0;
  border-radius: 0;
}
.sm-clean li {
  border-top: 1px solid rgba(50, 50, 50, 0.2);
}
.sm-clean > li:first-child {
  border-top: 0;
}
.sm-clean ul {
  background: rgba(30, 30, 30, 0.2);
}
.sm-clean ul a, .sm-clean ul a:hover, .sm-clean ul a:focus, .sm-clean ul a:active {
	font-family: Arial, Helvetica, sans-serif;
	text-transform: none;
  font-size: 18px;
  border-left: 8px solid transparent;
}
.sm-clean ul ul a,
.sm-clean ul ul a:hover,
.sm-clean ul ul a:focus,
.sm-clean ul ul a:active {
  border-left: 16px solid transparent;
}
.sm-clean ul ul ul a,
.sm-clean ul ul ul a:hover,
.sm-clean ul ul ul a:focus,
.sm-clean ul ul ul a:active {
  border-left: 24px solid transparent;
}
.sm-clean ul ul ul ul a,
.sm-clean ul ul ul ul a:hover,
.sm-clean ul ul ul ul a:focus,
.sm-clean ul ul ul ul a:active {
  border-left: 32px solid transparent;
}
.sm-clean ul ul ul ul ul a,
.sm-clean ul ul ul ul ul a:hover,
.sm-clean ul ul ul ul ul a:focus,
.sm-clean ul ul ul ul ul a:active {
  border-left: 40px solid transparent;
}

@media (min-width: 1024px) {
  /* Switch to desktop layout
  -----------------------------------------------
     These transform the menu tree from
     collapsible to desktop (navbar + dropdowns)
  -----------------------------------------------*/
  /* start... (it's not recommended editing these rules) */
  .sm-clean ul {
    position: absolute;
  }

  .sm-clean li {
    float: left;
  }

  .sm-clean.sm-rtl li {
    float: right;
  }

  .sm-clean ul li, .sm-clean.sm-rtl ul li, .sm-clean.sm-vertical li {
    float: none;
  }

  .sm-clean a {
    white-space: nowrap;
  }
  
  .sm-clean a:focus {
    outline: 0;
  }
  
  .sm-clean ul a, .sm-clean.sm-vertical a {
    white-space: normal;
  }

  .sm-clean .sm-nowrap > li > a, .sm-clean .sm-nowrap > li > :not(ul) a {
    white-space: nowrap;
  }

  /* ...end */
  .sm-clean {
    padding: 0 10px;
    background: transparent;
    -webkit-border-radius: 0px;
    -moz-border-radius: 0px;
    -ms-border-radius: 0px;
    -o-border-radius: 0px;
    border-radius: 0px;
  }
  .sm-clean a, .sm-clean a:hover, .sm-clean a:focus, .sm-clean a:active, .sm-clean a.highlighted {
    padding: 13px 12px 11px 12px;
    color: #eee;
	font-size: 14px;
    -webkit-border-radius: 0 !important;
    -moz-border-radius: 0 !important;
    -ms-border-radius: 0 !important;
    -o-border-radius: 0 !important;
    border-radius: 0 !important;
  }
  .sm-clean a {
	color: #999;
  }
  .sm-clean a.current {
    color: #eee;
  }
  .sm-clean a.disabled {
    color: #555;
  }
  .sm-clean a.has-submenu {
    padding-right: 24px;
  }
  .sm-clean a span.sub-arrow {
    top: 50%;
    margin-top: -2px;
    right: 12px;
    width: 0;
    height: 0;
    border-width: 4px;
    border-style: solid dashed dashed dashed;
    border-color: #999 transparent transparent transparent;
    background: transparent;
    -webkit-border-radius: 0;
    -moz-border-radius: 0;
    -ms-border-radius: 0;
    -o-border-radius: 0;
    border-radius: 0;
  }
  .sm-clean a.highlighted span.sub-arrow:before {
    display: none;
  }
  .sm-clean li {
    border-top: 0;
  }
  .sm-clean > li > ul:before,
  .sm-clean > li > ul:after {
    content: '';
    position: absolute;
    top: -18px;
    left: 30px;
    width: 0;
    height: 0;
    overflow: hidden;
    border-width: 9px;
    border-style: dashed dashed solid dashed;
    border-color: transparent transparent #555 transparent;
  }
  .sm-clean > li > ul:after {
    top: -16px;
    left: 31px;
    border-width: 8px;
    border-color: transparent transparent #000 transparent;
  }
  .sm-clean ul {
    border: 1px solid #555;
    padding: 5px 0;
    background: #000;
    -webkit-border-radius: 5px !important;
    -moz-border-radius: 5px !important;
    -ms-border-radius: 5px !important;
    -o-border-radius: 5px !important;
    border-radius: 5px !important;
    -webkit-box-shadow: none;
    -moz-box-shadow: none;
    box-shadow: none;
  }
  .sm-clean ul a, .sm-clean ul a:hover, .sm-clean ul a:focus, .sm-clean ul a:active, .sm-clean ul a.highlighted {
    border: 0 !important;
	font-size: 15px;
    padding: 10px 20px;
    color: #999;
  }
  .sm-clean ul a:hover, .sm-clean ul a:focus, .sm-clean ul a:active, .sm-clean ul a.highlighted {
    background: #000;
    color: #eee;
  }
  .sm-clean ul a.current {
    color: #eee;
  }
  .sm-clean ul a.disabled {
    background: #000;
    color: #555;
  }
  .sm-clean ul a.has-submenu {
    padding-right: 20px;
  }
  .sm-clean ul a span.sub-arrow {
    right: 8px;
    top: 50%;
    margin-top: -5px;
    border-width: 5px;
    border-style: dashed dashed dashed solid;
    border-color: transparent transparent transparent #999;
  }
  .sm-clean span.scroll-up,
  .sm-clean span.scroll-down {
    position: absolute;
    display: none;
    visibility: hidden;
    overflow: hidden;
    background: #000;
    height: 20px;
  }
  .sm-clean span.scroll-up:hover,
  .sm-clean span.scroll-down:hover {
    background: #333;
  }
  .sm-clean span.scroll-up:hover span.scroll-up-arrow, .sm-clean span.scroll-up:hover span.scroll-down-arrow {
    border-color: transparent transparent #eee transparent;
  }
  .sm-clean span.scroll-down:hover span.scroll-down-arrow {
    border-color: #eee transparent transparent transparent;
  }
  .sm-clean span.scroll-up-arrow, .sm-clean span.scroll-down-arrow {
    position: absolute;
    top: 0;
    left: 50%;
    margin-left: -6px;
    width: 0;
    height: 0;
    overflow: hidden;
    border-width: 6px;
    border-style: dashed dashed solid dashed;
    border-color: transparent transparent #999 transparent;
  }
  .sm-clean span.scroll-down-arrow {
    top: 8px;
    border-style: solid dashed dashed dashed;
    border-color: #999 transparent transparent transparent;
  }
  .sm-clean.sm-rtl a.has-submenu {
    padding-right: 12px;
    padding-left: 24px;
  }
  .sm-clean.sm-rtl a span.sub-arrow {
    right: auto;
    left: 12px;
  }
  .sm-clean.sm-rtl.sm-vertical a.has-submenu {
    padding: 10px 20px;
  }
  .sm-clean.sm-rtl.sm-vertical a span.sub-arrow {
    right: auto;
    left: 8px;
    border-style: dashed solid dashed dashed;
    border-color: transparent #999 transparent transparent;
  }
  .sm-clean.sm-rtl > li > ul:before {
    left: auto;
    right: 30px;
  }
  .sm-clean.sm-rtl > li > ul:after {
    left: auto;
    right: 31px;
  }
  .sm-clean.sm-rtl ul a.has-submenu {
    padding: 10px 20px !important;
  }
  .sm-clean.sm-rtl ul a span.sub-arrow {
    right: auto;
    left: 8px;
    border-style: dashed solid dashed dashed;
    border-color: transparent #999 transparent transparent;
  }
  .sm-clean.sm-vertical {
    padding: 10px 0;
    -webkit-border-radius: 5px;
    -moz-border-radius: 5px;
    -ms-border-radius: 5px;
    -o-border-radius: 5px;
    border-radius: 5px;
  }
  .sm-clean.sm-vertical a {
    padding: 10px 20px;
  }
  .sm-clean.sm-vertical a:hover, .sm-clean.sm-vertical a:focus, .sm-clean.sm-vertical a:active, .sm-clean.sm-vertical a.highlighted {
    background: #000;
  }
  .sm-clean.sm-vertical a.disabled {
    background: #222;
  }
  .sm-clean.sm-vertical a span.sub-arrow {
    right: 8px;
    top: 50%;
    margin-top: -5px;
    border-width: 5px;
    border-style: dashed dashed dashed solid;
    border-color: transparent transparent transparent #999;
  }
  .sm-clean.sm-vertical > li > ul:before,
  .sm-clean.sm-vertical > li > ul:after {
    display: none;
  }
  .sm-clean.sm-vertical ul a {
    padding: 10px 20px;
  }
  .sm-clean.sm-vertical ul a:hover, .sm-clean.sm-vertical ul a:focus, .sm-clean.sm-vertical ul a:active, .sm-clean.sm-vertical ul a.highlighted {
    background: #222;
  }
  .sm-clean.sm-vertical ul a.disabled {
    background: #000;
  }
}

/* ================================================================== */
/* This file has a mobile-to-tablet, and tablet-to-desktop breakpoint */
/* ================================================================== */
@media (max-width: 400px) {
  @-ms-viewport {
    width: 320px;
  }
}
.clear {
  clear: both;
  display: block;
  overflow: hidden;
  visibility: hidden;
  width: 0;
  height: 0;
}

.grid-container:before, .grid-5:before, .mobile-grid-5:before, .tablet-grid-5:before, .grid-10:before, .mobile-grid-10:before, .tablet-grid-10:before, .grid-15:before, .mobile-grid-15:before, .tablet-grid-15:before, .grid-20:before, .mobile-grid-20:before, .tablet-grid-20:before, .grid-25:before, .mobile-grid-25:before, .tablet-grid-25:before, .grid-30:before, .mobile-grid-30:before, .tablet-grid-30:before, .grid-35:before, .mobile-grid-35:before, .tablet-grid-35:before, .grid-40:before, .mobile-grid-40:before, .tablet-grid-40:before, .grid-45:before, .mobile-grid-45:before, .tablet-grid-45:before, .grid-50:before, .mobile-grid-50:before, .tablet-grid-50:before, .grid-55:before, .mobile-grid-55:before, .tablet-grid-55:before, .grid-60:before, .mobile-grid-60:before, .tablet-grid-60:before, .grid-65:before, .mobile-grid-65:before, .tablet-grid-65:before, .grid-70:before, .mobile-grid-70:before, .tablet-grid-70:before, .grid-75:before, .mobile-grid-75:before, .tablet-grid-75:before, .grid-80:before, .mobile-grid-80:before, .tablet-grid-80:before, .grid-85:before, .mobile-grid-85:before, .tablet-grid-85:before, .grid-90:before, .mobile-grid-90:before, .tablet-grid-90:before, .grid-95:before, .mobile-grid-95:before, .tablet-grid-95:before, .grid-100:before, .mobile-grid-100:before, .tablet-grid-100:before, .grid-33:before, .mobile-grid-33:before, .tablet-grid-33:before, .grid-66:before, .mobile-grid-66:before, .tablet-grid-66:before, .clearfix:before,
.grid-container:after,
.grid-5:after,
.mobile-grid-5:after,
.tablet-grid-5:after,
.grid-10:after,
.mobile-grid-10:after,
.tablet-grid-10:after,
.grid-15:after,
.mobile-grid-15:after,
.tablet-grid-15:after,
.grid-20:after,
.mobile-grid-20:after,
.tablet-grid-20:after,
.grid-25:after,
.mobile-grid-25:after,
.tablet-grid-25:after,
.grid-30:after,
.mobile-grid-30:after,
.tablet-grid-30:after,
.grid-35:after,
.mobile-grid-35:after,
.tablet-grid-35:after,
.grid-40:after,
.mobile-grid-40:after,
.tablet-grid-40:after,
.grid-45:after,
.mobile-grid-45:after,
.tablet-grid-45:after,
.grid-50:after,
.mobile-grid-50:after,
.tablet-grid-50:after,
.grid-55:after,
.mobile-grid-55:after,
.tablet-grid-55:after,
.grid-60:after,
.mobile-grid-60:after,
.tablet-grid-60:after,
.grid-65:after,
.mobile-grid-65:after,
.tablet-grid-65:after,
.grid-70:after,
.mobile-grid-70:after,
.tablet-grid-70:after,
.grid-75:after,
.mobile-grid-75:after,
.tablet-grid-75:after,
.grid-80:after,
.mobile-grid-80:after,
.tablet-grid-80:after,
.grid-85:after,
.mobile-grid-85:after,
.tablet-grid-85:after,
.grid-90:after,
.mobile-grid-90:after,
.tablet-grid-90:after,
.grid-95:after,
.mobile-grid-95:after,
.tablet-grid-95:after,
.grid-100:after,
.mobile-grid-100:after,
.tablet-grid-100:after,
.grid-33:after,
.mobile-grid-33:after,
.tablet-grid-33:after,
.grid-66:after,
.mobile-grid-66:after,
.tablet-grid-66:after,
.clearfix:after {
  content: ".";
  display: block;
  overflow: hidden;
  visibility: hidden;
  font-size: 0;
  line-height: 0;
  width: 0;
  height: 0;
}

.grid-container:after, .grid-5:after, .mobile-grid-5:after, .tablet-grid-5:after, .grid-10:after, .mobile-grid-10:after, .tablet-grid-10:after, .grid-15:after, .mobile-grid-15:after, .tablet-grid-15:after, .grid-20:after, .mobile-grid-20:after, .tablet-grid-20:after, .grid-25:after, .mobile-grid-25:after, .tablet-grid-25:after, .grid-30:after, .mobile-grid-30:after, .tablet-grid-30:after, .grid-35:after, .mobile-grid-35:after, .tablet-grid-35:after, .grid-40:after, .mobile-grid-40:after, .tablet-grid-40:after, .grid-45:after, .mobile-grid-45:after, .tablet-grid-45:after, .grid-50:after, .mobile-grid-50:after, .tablet-grid-50:after, .grid-55:after, .mobile-grid-55:after, .tablet-grid-55:after, .grid-60:after, .mobile-grid-60:after, .tablet-grid-60:after, .grid-65:after, .mobile-grid-65:after, .tablet-grid-65:after, .grid-70:after, .mobile-grid-70:after, .tablet-grid-70:after, .grid-75:after, .mobile-grid-75:after, .tablet-grid-75:after, .grid-80:after, .mobile-grid-80:after, .tablet-grid-80:after, .grid-85:after, .mobile-grid-85:after, .tablet-grid-85:after, .grid-90:after, .mobile-grid-90:after, .tablet-grid-90:after, .grid-95:after, .mobile-grid-95:after, .tablet-grid-95:after, .grid-100:after, .mobile-grid-100:after, .tablet-grid-100:after, .grid-33:after, .mobile-grid-33:after, .tablet-grid-33:after, .grid-66:after, .mobile-grid-66:after, .tablet-grid-66:after, .clearfix:after {
  clear: both;
}

.grid-container {
  margin-left: auto;
  margin-right: auto;
  max-width: 1020px;
  padding-left: 20px;
  padding-right: 20px;
}

.grid-5, .mobile-grid-5, .tablet-grid-5, .grid-10, .mobile-grid-10, .tablet-grid-10, .grid-15, .mobile-grid-15, .tablet-grid-15, .grid-20, .mobile-grid-20, .tablet-grid-20, .grid-25, .mobile-grid-25, .tablet-grid-25, .grid-30, .mobile-grid-30, .tablet-grid-30, .grid-35, .mobile-grid-35, .tablet-grid-35, .grid-40, .mobile-grid-40, .tablet-grid-40, .grid-45, .mobile-grid-45, .tablet-grid-45, .grid-50, .mobile-grid-50, .tablet-grid-50, .grid-55, .mobile-grid-55, .tablet-grid-55, .grid-60, .mobile-grid-60, .tablet-grid-60, .grid-65, .mobile-grid-65, .tablet-grid-65, .grid-70, .mobile-grid-70, .tablet-grid-70, .grid-75, .mobile-grid-75, .tablet-grid-75, .grid-80, .mobile-grid-80, .tablet-grid-80, .grid-85, .mobile-grid-85, .tablet-grid-85, .grid-90, .mobile-grid-90, .tablet-grid-90, .grid-95, .mobile-grid-95, .tablet-grid-95, .grid-100, .mobile-grid-100, .tablet-grid-100, .grid-33, .mobile-grid-33, .tablet-grid-33, .grid-66, .mobile-grid-66, .tablet-grid-66 {
  -moz-box-sizing: border-box;
  -webkit-box-sizing: border-box;
  box-sizing: border-box;
  padding-left: 20px;
  padding-right: 20px;
}

.grid-parent {
  padding-left: 0;
  padding-right: 0;
}

@media (max-width: 767px) {
  .mobile-push-5, .mobile-pull-5, .mobile-push-10, .mobile-pull-10, .mobile-push-15, .mobile-pull-15, .mobile-push-20, .mobile-pull-20, .mobile-push-25, .mobile-pull-25, .mobile-push-30, .mobile-pull-30, .mobile-push-35, .mobile-pull-35, .mobile-push-40, .mobile-pull-40, .mobile-push-45, .mobile-pull-45, .mobile-push-50, .mobile-pull-50, .mobile-push-55, .mobile-pull-55, .mobile-push-60, .mobile-pull-60, .mobile-push-65, .mobile-pull-65, .mobile-push-70, .mobile-pull-70, .mobile-push-75, .mobile-pull-75, .mobile-push-80, .mobile-pull-80, .mobile-push-85, .mobile-pull-85, .mobile-push-90, .mobile-pull-90, .mobile-push-95, .mobile-pull-95, .mobile-push-33, .mobile-pull-33, .mobile-push-66, .mobile-pull-66 {
    position: relative;
  }

  .hide-on-mobile {
    display: none !important;
  }

  .mobile-grid-5 {
    float: left;
    width: 5%;
  }

  .mobile-prefix-5 {
    margin-left: 5%;
  }

  .mobile-suffix-5 {
    margin-right: 5%;
  }

  .mobile-push-5 {
    left: 5%;
  }

  .mobile-pull-5 {
    left: -5%;
  }

  .mobile-grid-10 {
    float: left;
    width: 10%;
  }

  .mobile-prefix-10 {
    margin-left: 10%;
  }

  .mobile-suffix-10 {
    margin-right: 10%;
  }

  .mobile-push-10 {
    left: 10%;
  }

  .mobile-pull-10 {
    left: -10%;
  }

  .mobile-grid-15 {
    float: left;
    width: 15%;
  }

  .mobile-prefix-15 {
    margin-left: 15%;
  }

  .mobile-suffix-15 {
    margin-right: 15%;
  }

  .mobile-push-15 {
    left: 15%;
  }

  .mobile-pull-15 {
    left: -15%;
  }

  .mobile-grid-20 {
    float: left;
    width: 20%;
  }

  .mobile-prefix-20 {
    margin-left: 20%;
  }

  .mobile-suffix-20 {
    margin-right: 20%;
  }

  .mobile-push-20 {
    left: 20%;
  }

  .mobile-pull-20 {
    left: -20%;
  }

  .mobile-grid-25 {
    float: left;
    width: 25%;
  }

  .mobile-prefix-25 {
    margin-left: 25%;
  }

  .mobile-suffix-25 {
    margin-right: 25%;
  }

  .mobile-push-25 {
    left: 25%;
  }

  .mobile-pull-25 {
    left: -25%;
  }

  .mobile-grid-30 {
    float: left;
    width: 30%;
  }

  .mobile-prefix-30 {
    margin-left: 30%;
  }

  .mobile-suffix-30 {
    margin-right: 30%;
  }

  .mobile-push-30 {
    left: 30%;
  }

  .mobile-pull-30 {
    left: -30%;
  }

  .mobile-grid-35 {
    float: left;
    width: 35%;
  }

  .mobile-prefix-35 {
    margin-left: 35%;
  }

  .mobile-suffix-35 {
    margin-right: 35%;
  }

  .mobile-push-35 {
    left: 35%;
  }

  .mobile-pull-35 {
    left: -35%;
  }

  .mobile-grid-40 {
    float: left;
    width: 40%;
  }

  .mobile-prefix-40 {
    margin-left: 40%;
  }

  .mobile-suffix-40 {
    margin-right: 40%;
  }

  .mobile-push-40 {
    left: 40%;
  }

  .mobile-pull-40 {
    left: -40%;
  }

  .mobile-grid-45 {
    float: left;
    width: 45%;
  }

  .mobile-prefix-45 {
    margin-left: 45%;
  }

  .mobile-suffix-45 {
    margin-right: 45%;
  }

  .mobile-push-45 {
    left: 45%;
  }

  .mobile-pull-45 {
    left: -45%;
  }

  .mobile-grid-50 {
    float: left;
    width: 50%;
  }

  .mobile-prefix-50 {
    margin-left: 50%;
  }

  .mobile-suffix-50 {
    margin-right: 50%;
  }

  .mobile-push-50 {
    left: 50%;
  }

  .mobile-pull-50 {
    left: -50%;
  }

  .mobile-grid-55 {
    float: left;
    width: 55%;
  }

  .mobile-prefix-55 {
    margin-left: 55%;
  }

  .mobile-suffix-55 {
    margin-right: 55%;
  }

  .mobile-push-55 {
    left: 55%;
  }

  .mobile-pull-55 {
    left: -55%;
  }

  .mobile-grid-60 {
    float: left;
    width: 60%;
  }

  .mobile-prefix-60 {
    margin-left: 60%;
  }

  .mobile-suffix-60 {
    margin-right: 60%;
  }

  .mobile-push-60 {
    left: 60%;
  }

  .mobile-pull-60 {
    left: -60%;
  }

  .mobile-grid-65 {
    float: left;
    width: 65%;
  }

  .mobile-prefix-65 {
    margin-left: 65%;
  }

  .mobile-suffix-65 {
    margin-right: 65%;
  }

  .mobile-push-65 {
    left: 65%;
  }

  .mobile-pull-65 {
    left: -65%;
  }

  .mobile-grid-70 {
    float: left;
    width: 70%;
  }

  .mobile-prefix-70 {
    margin-left: 70%;
  }

  .mobile-suffix-70 {
    margin-right: 70%;
  }

  .mobile-push-70 {
    left: 70%;
  }

  .mobile-pull-70 {
    left: -70%;
  }

  .mobile-grid-75 {
    float: left;
    width: 75%;
  }

  .mobile-prefix-75 {
    margin-left: 75%;
  }

  .mobile-suffix-75 {
    margin-right: 75%;
  }

  .mobile-push-75 {
    left: 75%;
  }

  .mobile-pull-75 {
    left: -75%;
  }

  .mobile-grid-80 {
    float: left;
    width: 80%;
  }

  .mobile-prefix-80 {
    margin-left: 80%;
  }

  .mobile-suffix-80 {
    margin-right: 80%;
  }

  .mobile-push-80 {
    left: 80%;
  }

  .mobile-pull-80 {
    left: -80%;
  }

  .mobile-grid-85 {
    float: left;
    width: 85%;
  }

  .mobile-prefix-85 {
    margin-left: 85%;
  }

  .mobile-suffix-85 {
    margin-right: 85%;
  }

  .mobile-push-85 {
    left: 85%;
  }

  .mobile-pull-85 {
    left: -85%;
  }

  .mobile-grid-90 {
    float: left;
    width: 90%;
  }

  .mobile-prefix-90 {
    margin-left: 90%;
  }

  .mobile-suffix-90 {
    margin-right: 90%;
  }

  .mobile-push-90 {
    left: 90%;
  }

  .mobile-pull-90 {
    left: -90%;
  }

  .mobile-grid-95 {
    float: left;
    width: 95%;
  }

  .mobile-prefix-95 {
    margin-left: 95%;
  }

  .mobile-suffix-95 {
    margin-right: 95%;
  }

  .mobile-push-95 {
    left: 95%;
  }

  .mobile-pull-95 {
    left: -95%;
  }

  .mobile-grid-33 {
    float: left;
    width: 33.33333%;
  }

  .mobile-prefix-33 {
    margin-left: 33.33333%;
  }

  .mobile-suffix-33 {
    margin-right: 33.33333%;
  }

  .mobile-push-33 {
    left: 33.33333%;
  }

  .mobile-pull-33 {
    left: -33.33333%;
  }

  .mobile-grid-66 {
    float: left;
    width: 66.66667%;
  }

  .mobile-prefix-66 {
    margin-left: 66.66667%;
  }

  .mobile-suffix-66 {
    margin-right: 66.66667%;
  }

  .mobile-push-66 {
    left: 66.66667%;
  }

  .mobile-pull-66 {
    left: -66.66667%;
  }

  .mobile-grid-100 {
    clear: both;
    width: 100%;
  }
}
@media (min-width: 768px) and (max-width: 1024px) {
  .tablet-push-5, .tablet-pull-5, .tablet-push-10, .tablet-pull-10, .tablet-push-15, .tablet-pull-15, .tablet-push-20, .tablet-pull-20, .tablet-push-25, .tablet-pull-25, .tablet-push-30, .tablet-pull-30, .tablet-push-35, .tablet-pull-35, .tablet-push-40, .tablet-pull-40, .tablet-push-45, .tablet-pull-45, .tablet-push-50, .tablet-pull-50, .tablet-push-55, .tablet-pull-55, .tablet-push-60, .tablet-pull-60, .tablet-push-65, .tablet-pull-65, .tablet-push-70, .tablet-pull-70, .tablet-push-75, .tablet-pull-75, .tablet-push-80, .tablet-pull-80, .tablet-push-85, .tablet-pull-85, .tablet-push-90, .tablet-pull-90, .tablet-push-95, .tablet-pull-95, .tablet-push-33, .tablet-pull-33, .tablet-push-66, .tablet-pull-66 {
    position: relative;
  }

  .hide-on-tablet {
    display: none !important;
  }

  .tablet-grid-5 {
    float: left;
    width: 5%;
  }

  .tablet-prefix-5 {
    margin-left: 5%;
  }

  .tablet-suffix-5 {
    margin-right: 5%;
  }

  .tablet-push-5 {
    left: 5%;
  }

  .tablet-pull-5 {
    left: -5%;
  }

  .tablet-grid-10 {
    float: left;
    width: 10%;
  }

  .tablet-prefix-10 {
    margin-left: 10%;
  }

  .tablet-suffix-10 {
    margin-right: 10%;
  }

  .tablet-push-10 {
    left: 10%;
  }

  .tablet-pull-10 {
    left: -10%;
  }

  .tablet-grid-15 {
    float: left;
    width: 15%;
  }

  .tablet-prefix-15 {
    margin-left: 15%;
  }

  .tablet-suffix-15 {
    margin-right: 15%;
  }

  .tablet-push-15 {
    left: 15%;
  }

  .tablet-pull-15 {
    left: -15%;
  }

  .tablet-grid-20 {
    float: left;
    width: 20%;
  }

  .tablet-prefix-20 {
    margin-left: 20%;
  }

  .tablet-suffix-20 {
    margin-right: 20%;
  }

  .tablet-push-20 {
    left: 20%;
  }

  .tablet-pull-20 {
    left: -20%;
  }

  .tablet-grid-25 {
    float: left;
    width: 25%;
  }

  .tablet-prefix-25 {
    margin-left: 25%;
  }

  .tablet-suffix-25 {
    margin-right: 25%;
  }

  .tablet-push-25 {
    left: 25%;
  }

  .tablet-pull-25 {
    left: -25%;
  }

  .tablet-grid-30 {
    float: left;
    width: 30%;
  }

  .tablet-prefix-30 {
    margin-left: 30%;
  }

  .tablet-suffix-30 {
    margin-right: 30%;
  }

  .tablet-push-30 {
    left: 30%;
  }

  .tablet-pull-30 {
    left: -30%;
  }

  .tablet-grid-35 {
    float: left;
    width: 35%;
  }

  .tablet-prefix-35 {
    margin-left: 35%;
  }

  .tablet-suffix-35 {
    margin-right: 35%;
  }

  .tablet-push-35 {
    left: 35%;
  }

  .tablet-pull-35 {
    left: -35%;
  }

  .tablet-grid-40 {
    float: left;
    width: 40%;
  }

  .tablet-prefix-40 {
    margin-left: 40%;
  }

  .tablet-suffix-40 {
    margin-right: 40%;
  }

  .tablet-push-40 {
    left: 40%;
  }

  .tablet-pull-40 {
    left: -40%;
  }

  .tablet-grid-45 {
    float: left;
    width: 45%;
  }

  .tablet-prefix-45 {
    margin-left: 45%;
  }

  .tablet-suffix-45 {
    margin-right: 45%;
  }

  .tablet-push-45 {
    left: 45%;
  }

  .tablet-pull-45 {
    left: -45%;
  }

  .tablet-grid-50 {
    float: left;
    width: 50%;
  }

  .tablet-prefix-50 {
    margin-left: 50%;
  }

  .tablet-suffix-50 {
    margin-right: 50%;
  }

  .tablet-push-50 {
    left: 50%;
  }

  .tablet-pull-50 {
    left: -50%;
  }

  .tablet-grid-55 {
    float: left;
    width: 55%;
  }

  .tablet-prefix-55 {
    margin-left: 55%;
  }

  .tablet-suffix-55 {
    margin-right: 55%;
  }

  .tablet-push-55 {
    left: 55%;
  }

  .tablet-pull-55 {
    left: -55%;
  }

  .tablet-grid-60 {
    float: left;
    width: 60%;
  }

  .tablet-prefix-60 {
    margin-left: 60%;
  }

  .tablet-suffix-60 {
    margin-right: 60%;
  }

  .tablet-push-60 {
    left: 60%;
  }

  .tablet-pull-60 {
    left: -60%;
  }

  .tablet-grid-65 {
    float: left;
    width: 65%;
  }

  .tablet-prefix-65 {
    margin-left: 65%;
  }

  .tablet-suffix-65 {
    margin-right: 65%;
  }

  .tablet-push-65 {
    left: 65%;
  }

  .tablet-pull-65 {
    left: -65%;
  }

  .tablet-grid-70 {
    float: left;
    width: 70%;
  }

  .tablet-prefix-70 {
    margin-left: 70%;
  }

  .tablet-suffix-70 {
    margin-right: 70%;
  }

  .tablet-push-70 {
    left: 70%;
  }

  .tablet-pull-70 {
    left: -70%;
  }

  .tablet-grid-75 {
    float: left;
    width: 75%;
  }

  .tablet-prefix-75 {
    margin-left: 75%;
  }

  .tablet-suffix-75 {
    margin-right: 75%;
  }

  .tablet-push-75 {
    left: 75%;
  }

  .tablet-pull-75 {
    left: -75%;
  }

  .tablet-grid-80 {
    float: left;
    width: 80%;
  }

  .tablet-prefix-80 {
    margin-left: 80%;
  }

  .tablet-suffix-80 {
    margin-right: 80%;
  }

  .tablet-push-80 {
    left: 80%;
  }

  .tablet-pull-80 {
    left: -80%;
  }

  .tablet-grid-85 {
    float: left;
    width: 85%;
  }

  .tablet-prefix-85 {
    margin-left: 85%;
  }

  .tablet-suffix-85 {
    margin-right: 85%;
  }

  .tablet-push-85 {
    left: 85%;
  }

  .tablet-pull-85 {
    left: -85%;
  }

  .tablet-grid-90 {
    float: left;
    width: 90%;
  }

  .tablet-prefix-90 {
    margin-left: 90%;
  }

  .tablet-suffix-90 {
    margin-right: 90%;
  }

  .tablet-push-90 {
    left: 90%;
  }

  .tablet-pull-90 {
    left: -90%;
  }

  .tablet-grid-95 {
    float: left;
    width: 95%;
  }

  .tablet-prefix-95 {
    margin-left: 95%;
  }

  .tablet-suffix-95 {
    margin-right: 95%;
  }

  .tablet-push-95 {
    left: 95%;
  }

  .tablet-pull-95 {
    left: -95%;
  }

  .tablet-grid-33 {
    float: left;
    width: 33.33333%;
  }

  .tablet-prefix-33 {
    margin-left: 33.33333%;
  }

  .tablet-suffix-33 {
    margin-right: 33.33333%;
  }

  .tablet-push-33 {
    left: 33.33333%;
  }

  .tablet-pull-33 {
    left: -33.33333%;
  }

  .tablet-grid-66 {
    float: left;
    width: 66.66667%;
  }

  .tablet-prefix-66 {
    margin-left: 66.66667%;
  }

  .tablet-suffix-66 {
    margin-right: 66.66667%;
  }

  .tablet-push-66 {
    left: 66.66667%;
  }

  .tablet-pull-66 {
    left: -66.66667%;
  }

  .tablet-grid-100 {
    clear: both;
    width: 100%;
  }
}
@media (min-width: 1025px) {
  .push-5, .pull-5, .push-10, .pull-10, .push-15, .pull-15, .push-20, .pull-20, .push-25, .pull-25, .push-30, .pull-30, .push-35, .pull-35, .push-40, .pull-40, .push-45, .pull-45, .push-50, .pull-50, .push-55, .pull-55, .push-60, .pull-60, .push-65, .pull-65, .push-70, .pull-70, .push-75, .pull-75, .push-80, .pull-80, .push-85, .pull-85, .push-90, .pull-90, .push-95, .pull-95, .push-33, .pull-33, .push-66, .pull-66 {
    position: relative;
  }

  .hide-on-desktop {
    display: none !important;
  }

  .grid-5 {
    float: left;
    width: 5%;
  }

  .prefix-5 {
    margin-left: 5%;
  }

  .suffix-5 {
    margin-right: 5%;
  }

  .push-5 {
    left: 5%;
  }

  .pull-5 {
    left: -5%;
  }

  .grid-10 {
    float: left;
    width: 10%;
  }

  .prefix-10 {
    margin-left: 10%;
  }

  .suffix-10 {
    margin-right: 10%;
  }

  .push-10 {
    left: 10%;
  }

  .pull-10 {
    left: -10%;
  }

  .grid-15 {
    float: left;
    width: 15%;
  }

  .prefix-15 {
    margin-left: 15%;
  }

  .suffix-15 {
    margin-right: 15%;
  }

  .push-15 {
    left: 15%;
  }

  .pull-15 {
    left: -15%;
  }

  .grid-20 {
    float: left;
    width: 20%;
  }

  .prefix-20 {
    margin-left: 20%;
  }

  .suffix-20 {
    margin-right: 20%;
  }

  .push-20 {
    left: 20%;
  }

  .pull-20 {
    left: -20%;
  }

  .grid-25 {
    float: left;
    width: 25%;
  }

  .prefix-25 {
    margin-left: 25%;
  }

  .suffix-25 {
    margin-right: 25%;
  }

  .push-25 {
    left: 25%;
  }

  .pull-25 {
    left: -25%;
  }

  .grid-30 {
    float: left;
    width: 30%;
  }

  .prefix-30 {
    margin-left: 30%;
  }

  .suffix-30 {
    margin-right: 30%;
  }

  .push-30 {
    left: 30%;
  }

  .pull-30 {
    left: -30%;
  }

  .grid-35 {
    float: left;
    width: 35%;
  }

  .prefix-35 {
    margin-left: 35%;
  }

  .suffix-35 {
    margin-right: 35%;
  }

  .push-35 {
    left: 35%;
  }

  .pull-35 {
    left: -35%;
  }

  .grid-40 {
    float: left;
    width: 40%;
  }

  .prefix-40 {
    margin-left: 40%;
  }

  .suffix-40 {
    margin-right: 40%;
  }

  .push-40 {
    left: 40%;
  }

  .pull-40 {
    left: -40%;
  }

  .grid-45 {
    float: left;
    width: 45%;
  }

  .prefix-45 {
    margin-left: 45%;
  }

  .suffix-45 {
    margin-right: 45%;
  }

  .push-45 {
    left: 45%;
  }

  .pull-45 {
    left: -45%;
  }

  .grid-50 {
    float: left;
    width: 50%;
  }

  .prefix-50 {
    margin-left: 50%;
  }

  .suffix-50 {
    margin-right: 50%;
  }

  .push-50 {
    left: 50%;
  }

  .pull-50 {
    left: -50%;
  }

  .grid-55 {
    float: left;
    width: 55%;
  }

  .prefix-55 {
    margin-left: 55%;
  }

  .suffix-55 {
    margin-right: 55%;
  }

  .push-55 {
    left: 55%;
  }

  .pull-55 {
    left: -55%;
  }

  .grid-60 {
    float: left;
    width: 60%;
  }

  .prefix-60 {
    margin-left: 60%;
  }

  .suffix-60 {
    margin-right: 60%;
  }

  .push-60 {
    left: 60%;
  }

  .pull-60 {
    left: -60%;
  }

  .grid-65 {
    float: left;
    width: 65%;
  }

  .prefix-65 {
    margin-left: 65%;
  }

  .suffix-65 {
    margin-right: 65%;
  }

  .push-65 {
    left: 65%;
  }

  .pull-65 {
    left: -65%;
  }

  .grid-70 {
    float: left;
    width: 70%;
  }

  .prefix-70 {
    margin-left: 70%;
  }

  .suffix-70 {
    margin-right: 70%;
  }

  .push-70 {
    left: 70%;
  }

  .pull-70 {
    left: -70%;
  }

  .grid-75 {
    float: left;
    width: 75%;
  }

  .prefix-75 {
    margin-left: 75%;
  }

  .suffix-75 {
    margin-right: 75%;
  }

  .push-75 {
    left: 75%;
  }

  .pull-75 {
    left: -75%;
  }

  .grid-80 {
    float: left;
    width: 80%;
  }

  .prefix-80 {
    margin-left: 80%;
  }

  .suffix-80 {
    margin-right: 80%;
  }

  .push-80 {
    left: 80%;
  }

  .pull-80 {
    left: -80%;
  }

  .grid-85 {
    float: left;
    width: 85%;
  }

  .prefix-85 {
    margin-left: 85%;
  }

  .suffix-85 {
    margin-right: 85%;
  }

  .push-85 {
    left: 85%;
  }

  .pull-85 {
    left: -85%;
  }

  .grid-90 {
    float: left;
    width: 90%;
  }

  .prefix-90 {
    margin-left: 90%;
  }

  .suffix-90 {
    margin-right: 90%;
  }

  .push-90 {
    left: 90%;
  }

  .pull-90 {
    left: -90%;
  }

  .grid-95 {
    float: left;
    width: 95%;
  }

  .prefix-95 {
    margin-left: 95%;
  }

  .suffix-95 {
    margin-right: 95%;
  }

  .push-95 {
    left: 95%;
  }

  .pull-95 {
    left: -95%;
  }

  .grid-33 {
    float: left;
    width: 33.33333%;
  }

  .prefix-33 {
    margin-left: 33.33333%;
  }

  .suffix-33 {
    margin-right: 33.33333%;
  }

  .push-33 {
    left: 33.33333%;
  }

  .pull-33 {
    left: -33.33333%;
  }

  .grid-66 {
    float: left;
    width: 66.66667%;
  }

  .prefix-66 {
    margin-left: 66.66667%;
  }

  .suffix-66 {
    margin-right: 66.66667%;
  }

  .push-66 {
    left: 66.66667%;
  }

  .pull-66 {
    left: -66.66667%;
  }

  .grid-100 {
    clear: both;
    width: 100%;
  }
}
